CarpenterAdaptiveRegion class final

Inheritance

Constructors

CarpenterAdaptiveRegion({Key? key, required Widget primary, required Widget region, required CarpenterRegionRole role, required CarpenterAdaptiveRegionPolicy policy, required bool regionVisible, ValueChanged<bool>? onRegionVisibilityChanged, double splitPosition = 0.65, ValueChanged<double>? onSplitPositionChanged, CarpenterViewportPolicy viewportPolicy = const CarpenterViewportPolicy(), FocusNode? primaryFocusNode, FocusNode? regionFocusNode, String? overlaySemanticLabel})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onRegionVisibilityChanged ValueChanged<bool>?
final
onSplitPositionChanged ValueChanged<double>?
final
overlaySemanticLabel String?
final
policy CarpenterAdaptiveRegionPolicy
final
primary Widget
final
primaryFocusNode FocusNode?
final
region Widget
final
regionFocusNode FocusNode?
final
regionVisible bool
final
role CarpenterRegionRole
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
splitPosition double
final
viewportPolicy CarpenterViewportPolicy
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<CarpenterAdaptiveRegion>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited