CarpenterAdaptiveSplitLayout class final

Adaptive two/three-region split with optional persisted split position.

Inheritance

Constructors

CarpenterAdaptiveSplitLayout({Key? key, required Widget primary, required Widget secondary, Widget? inspector, CarpenterSplitNarrowRegion narrowRegion = CarpenterSplitNarrowRegion.primary, double breakpoint = 840, double initialRatio = .38, double minPrimaryWidth = 260, double minSecondaryWidth = 320, bool resizable = true, CarpenterPageRestorationController? restoration, String restorationKey = 'split-ratio'})
const

Properties

breakpoint double
final
hashCode int
The hash code for this object.
no setterinherited
initialRatio double
final
inspector Widget?
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
minPrimaryWidth double
final
minSecondaryWidth double
final
narrowRegion CarpenterSplitNarrowRegion
final
primary Widget
final
resizable bool
final
restoration CarpenterPageRestorationController?
final
restorationKey String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secondary Widget
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<CarpenterAdaptiveSplitLayout>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited