CarpenterCalendar constructor
const
CarpenterCalendar({})
Creates a controlled date picker. The displayed month starts at initialMonth, selected, or the current date in that order. Rebuild with the date received by onChanged to update the selection. Date bounds are inclusive and compare calendar dates, not times.
Implementation
const CarpenterCalendar({
super.key,
this.selected,
required this.onChanged,
this.firstDate,
this.lastDate,
this.initialMonth,
});