CarpenterCard class final
A semantic surface grouping one related block of content.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- CarpenterCard
Constructors
- CarpenterCard({Key? key, required Widget child, String? semanticLabel, bool padded = true, EdgeInsetsGeometry? padding, CarpenterCardSurfaceRole surfaceRole = CarpenterCardSurfaceRole.overlay, FeedbackColorRole? feedbackRole, Color? backgroundColor, Color? borderColor, bool bordered = true, ShapeRole shape = ShapeRole.rounded, Clip clipBehavior = Clip.antiAlias})
-
const
- CarpenterCard.feedback({Key? key, required Widget child, required FeedbackColorRole role, String? semanticLabel, bool padded = true, EdgeInsetsGeometry? padding, bool bordered = true, ShapeRole shape = ShapeRole.rounded, Clip clipBehavior = Clip.antiAlias})
-
const
Properties
- backgroundColor → Color?
-
Compatibility escape hatch for integrations that still need a raw color.
New code should prefer surfaceRole or CarpenterCard.feedback.
final
- borderColor → Color?
-
Compatibility escape hatch for integrations that still need a raw color.
New code should prefer semantic card surfaces.
final
- bordered → bool
-
final
- child → Widget
-
final
- clipBehavior → Clip
-
final
- feedbackRole → FeedbackColorRole?
-
When set, feedback colors supersede surfaceRole.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- padded → bool
-
Compatibility switch for the default Carpenter card inset.
final
- padding → EdgeInsetsGeometry?
-
Compatibility escape hatch for layouts that cannot use the default card
inset yet. Prefer Carpenter spacing roles when composing new surfaces.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- semanticLabel → String?
-
final
- shape → ShapeRole
-
final
- surfaceRole → CarpenterCardSurfaceRole
-
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited