description property
Optional supporting text explaining the choice without replacing its accessible name.
Implementation
final String? description;
Optional supporting text explaining the choice without replacing its accessible name.
final String? description;