value property
Current tri-state selection. Mixed is supplied by the owner, not reached by ordinary toggling.
Implementation
final CheckboxValue value;
Current tri-state selection. Mixed is supplied by the owner, not reached by ordinary toggling.
final CheckboxValue value;