presentation property
CarpenterCommandPresentation
get
presentation
Semantic prominence requested when this command is rendered as an action.
Implementation
CarpenterCommandPresentation get presentation;
Semantic prominence requested when this command is rendered as an action.
CarpenterCommandPresentation get presentation;