CarpenterCommandBinding<I> class final

Binds a command to the concrete input and optional shortcuts used by a surface.

Constructors

CarpenterCommandBinding({required CarpenterCommand<I> command, required I input, List<ShortcutActivator>? shortcuts})
Creates a binding from command and input, optionally overriding its shortcuts.
const

Properties

command CarpenterCommand<I>
Command invoked by this binding.
final
hashCode int
The hash code for this object.
no setterinherited
input → I
Input supplied when the bound command is invoked.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shortcuts List<ShortcutActivator>?
Shortcut activators for this binding, or null to use the command defaults.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited