command property
Command whose live availability, presentation, execution state, and title drive the rendered button.
Implementation
final CarpenterCommand<I> command;
Command whose live availability, presentation, execution state, and title drive the rendered button.
final CarpenterCommand<I> command;