CarpenterDragPayload<T> class final

Annotations

Constructors

CarpenterDragPayload({required T data, Object? id, Set<CarpenterDragOperation> allowedOperations = const {CarpenterDragOperation.move}, Map<String, Object?> metadata = const {}})
const

Properties

allowedOperations Set<CarpenterDragOperation>
final
data → T
final
hashCode int
The hash code for this object.
no setterinherited
id Object?
final
metadata Map<String, Object?>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<R>(R transform(T value)) CarpenterDragPayload<R>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
supports(CarpenterDragOperation operation) bool
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited