CarpenterDropdown class final

A controlled action-menu trigger.

Inheritance

Constructors

CarpenterDropdown({Key? key, required bool open, required ValueChanged<bool> onOpenChanged, required String label, required List<CarpenterMenuItem> items, CarpenterIconSource? icon, ActionColorRole colorRole = ActionColorRole.neutral, ActionProminence prominence = ActionProminence.normal, ControlSize size = ControlSize.medium, CarpenterShape shape = CarpenterShape.rounded, OverlayPlacement placement = OverlayPlacement.bottomStart, List<OverlayPlacement> fallbackPlacements = const [], FocusNode? focusNode, bool autofocus = false, String? semanticLabel})
const
CarpenterDropdown.icon({Key? key, required bool open, required ValueChanged<bool> onOpenChanged, required String label, required List<CarpenterMenuItem> items, required CarpenterIconSource icon, ActionColorRole colorRole = ActionColorRole.neutral, ActionProminence prominence = ActionProminence.normal, ControlSize size = ControlSize.medium, CarpenterShape shape = CarpenterShape.rounded, OverlayPlacement placement = OverlayPlacement.bottomStart, List<OverlayPlacement> fallbackPlacements = const [], FocusNode? focusNode, bool autofocus = false, String? semanticLabel})
const

Properties

autofocus bool
final
colorRole ActionColorRole
final
fallbackPlacements List<OverlayPlacement>
final
focusNode FocusNode?
final
hashCode int
The hash code for this object.
no setterinherited
icon CarpenterIconSource?
final
items List<CarpenterMenuItem>
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
label String
final
onOpenChanged ValueChanged<bool>
final
open bool
final
placement OverlayPlacement
final
prominence ActionProminence
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
semanticLabel String?
final
shape CarpenterShape
final
size ControlSize
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited