columns property
Ordered column descriptors supplying headers, cell builders, horizontal alignment, and width policy. Use stable unique IDs to address footer cells.
Implementation
final List<CarpenterTableColumn<T>> columns;
Ordered column descriptors supplying headers, cell builders, horizontal alignment, and width policy. Use stable unique IDs to address footer cells.
final List<CarpenterTableColumn<T>> columns;