CarpenterEditorControllerBase<TRecord> class final

Inheritance
Implemented types

Constructors

CarpenterEditorControllerBase({required CarpenterEditorMode mode, required List<CarpenterFieldBinding> fields, required Future<TRecord> onSave(Map<CarpenterFieldId, Object?> values), VoidCallback? onCancel})

Properties

fields List<CarpenterFieldBinding>
final
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
mode CarpenterEditorMode
final
onCancel VoidCallback?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value CarpenterEditorState
The current value stored in this notifier.
getter/setter pairinherited
values Map<CarpenterFieldId, Object?>
no setter

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
cancel() → void
override
dispose() → void
Discards any resources used by the object.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
save() Future<TRecord?>
override
toString() String
A string representation of this object.
inherited
validate() Future<bool>
override

Operators

operator ==(Object other) bool
The equality operator.
inherited