CarpenterFeedbackStyle class final

Resolved passive feedback colors for one semantic feedback role.

Annotations

Constructors

CarpenterFeedbackStyle({required Color background, required Color foreground})
Creates background and foreground colors for one feedback role.
const

Properties

background Color
Semantic feedback surface/background color.
final
foreground Color
Semantic feedback foreground color.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({Color? background, Color? foreground}) CarpenterFeedbackStyle
Returns this feedback style with supplied surface or foreground colors replaced.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited