CarpenterFieldDescriptor<TValue> class final

Annotations

Constructors

CarpenterFieldDescriptor({required CarpenterFieldId id, required String label, String? description, String formatter(TValue value)?, TValue parser(String raw)?, FutureOr<CarpenterValidationResult> validator(TValue value)?, bool visibility(CarpenterFieldContext context)?, bool editability(CarpenterFieldContext context)?})
const

Properties

description String?
final
editability bool Function(CarpenterFieldContext context)?
final
formatter String Function(TValue value)?
final
hashCode int
The hash code for this object.
no setterinherited
id CarpenterFieldId
final
label String
final
parser → TValue Function(String raw)?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
validator FutureOr<CarpenterValidationResult> Function(TValue value)?
final
visibility bool Function(CarpenterFieldContext context)?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited