required property
Whether to append a required marker to label. This is presentational and does not make the child value mandatory.
Implementation
final bool required;
Whether to append a required marker to label. This is presentational and does not make the child value mandatory.
final bool required;