commandsOf static method
Returns the command list exposed by the nearest hotkey scope.
Implementation
static List<CarpenterCommand<void>> commandsOf(BuildContext context) =>
_bindingOf(context).commands;
Returns the command list exposed by the nearest hotkey scope.
static List<CarpenterCommand<void>> commandsOf(BuildContext context) =>
_bindingOf(context).commands;