CarpenterInputCapabilities class final
- Annotations
Constructors
- CarpenterInputCapabilities({required bool precisePointer, required bool hover, required bool touch, required bool hardwareKeyboard})
-
const
Properties
- hardwareKeyboard → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hover → bool
-
final
- precisePointer → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- touch → bool
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- hybrid → const CarpenterInputCapabilities
- pointerOriented → const CarpenterInputCapabilities
- touchOriented → const CarpenterInputCapabilities