CarpenterInputMask class final

Annotations

Constructors

CarpenterInputMask(String pattern, {String placeholderCharacter = '_'})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
pattern String
final
placeholder String
no setter
placeholderCharacter String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
slotCount int
no setter

Methods

format(String value) String
isComplete(String value) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
unmask(String value) String

Operators

operator ==(Object other) bool
The equality operator.
inherited