CarpenterMaskedInput class final
Text input that applies a semantic mask while reusing the standard Carpenter field pipeline.
Mask tokens are # for digits, A for letters and * for alphanumeric
characters. Prefix a token with \\ to render it literally.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- CarpenterMaskedInput
Constructors
-
CarpenterMaskedInput({Key? key, required TextEditingController controller, required CarpenterInputMask mask, String? label, String? placeholder, String? description, CarpenterFieldFeedback? feedback, String? errorText, String? semanticLabel, bool required = false, FieldAvailability availability = FieldAvailability.enabled, FieldSize size = FieldSize.medium, CarpenterShape shape = CarpenterShape.rounded, CarpenterIconSource? leadingIcon, CarpenterActionDescriptor? trailingAction, ValueChanged<
String> ? onChanged, ValueChanged<String> ? onSubmitted, TextInputType? keyboardType, TextInputAction? textInputAction, FocusNode? focusNode, bool autofocus = false}) -
const
Properties
- autofocus → bool
-
final
- availability → FieldAvailability
-
final
- controller → TextEditingController
-
final
- description → String?
-
final
- errorText → String?
-
final
- feedback → CarpenterFieldFeedback?
-
final
- focusNode → FocusNode?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- keyboardType → TextInputType?
-
final
- label → String?
-
final
- leadingIcon → CarpenterIconSource?
-
final
- mask → CarpenterInputMask
-
final
-
onChanged
→ ValueChanged<
String> ? -
final
-
onSubmitted
→ ValueChanged<
String> ? -
final
- placeholder → String?
-
final
- required → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- semanticLabel → String?
-
final
- shape → CarpenterShape
-
final
- size → FieldSize
-
final
- textInputAction → TextInputAction?
-
final
- trailingAction → CarpenterActionDescriptor?
-
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
-
unmask(
String value) → String
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited