CarpenterNumberInput class final

Controlled numeric field with locale-tolerant decimal parsing.

Inheritance

Constructors

CarpenterNumberInput({Key? key, required num? value, required ValueChanged<num?>? onChanged, String? label, String? placeholder, String? description, CarpenterFieldFeedback? feedback, String? errorText, String? semanticLabel, bool required = false, FieldAvailability availability = FieldAvailability.enabled, FieldSize size = FieldSize.medium, CarpenterShape shape = CarpenterShape.rounded, bool allowDecimal = true, bool allowNegative = true, num? min, num? max, ValueChanged<num?>? onSubmitted, FocusNode? focusNode, bool autofocus = false})
const

Properties

allowDecimal bool
final
allowNegative bool
final
autofocus bool
final
availability FieldAvailability
final
description String?
final
errorText String?
final
feedback CarpenterFieldFeedback?
final
focusNode FocusNode?
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
label String?
final
max num?
final
min num?
final
onChanged ValueChanged<num?>?
final
onSubmitted ValueChanged<num?>?
final
placeholder String?
final
required bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
semanticLabel String?
final
shape CarpenterShape
final
size FieldSize
final
value num?
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<CarpenterNumberInput>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited