CarpenterObjectPage class final

Inheritance

Constructors

CarpenterObjectPage({Key? key, required String title, required Widget primaryContent, String? subtitle, CarpenterPageStatus? status, Widget? breadcrumbs, Widget? metadata, Widget? secondaryRegion, bool secondaryVisible = true, ValueChanged<bool>? onSecondaryVisibilityChanged, CarpenterAdaptiveRegionPolicy secondaryPolicy = CarpenterBreakpointRegionPolicy.secondary, double splitPosition = 0.7, ValueChanged<double>? onSplitPositionChanged, List<CarpenterActionDescriptor> primaryActions = const [], List<CarpenterActionDescriptor> secondaryActions = const [], List<CarpenterActionDescriptor> destructiveActions = const [], CarpenterPageHeaderBehavior headerBehavior = CarpenterPageHeaderBehavior.sticky, String? semanticLabel})
const

Properties

final
destructiveActions List<CarpenterActionDescriptor>
final
hashCode int
The hash code for this object.
no setterinherited
headerBehavior CarpenterPageHeaderBehavior
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
metadata Widget?
final
onSecondaryVisibilityChanged ValueChanged<bool>?
final
onSplitPositionChanged ValueChanged<double>?
final
primaryActions List<CarpenterActionDescriptor>
final
primaryContent Widget
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secondaryActions List<CarpenterActionDescriptor>
final
secondaryPolicy CarpenterAdaptiveRegionPolicy
final
secondaryRegion Widget?
final
secondaryVisible bool
final
semanticLabel String?
final
splitPosition double
final
status CarpenterPageStatus?
final
subtitle String?
final
title String
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited