CarpenterOverlayTheme class final
- Annotations
Constructors
Properties
- background → Color
-
final
- border → Color
-
final
- foreground → Color
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hovered → Color
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scrim → Color
-
final
- selected → Color
-
final
- supporting → Color
-
final
- tooltipBackground → Color
-
final
- tooltipForeground → Color
-
final
Methods
-
copyWith(
{Color? background, Color? foreground, Color? supporting, Color? border, Color? hovered, Color? selected, Color? scrim, Color? tooltipBackground, Color? tooltipForeground}) → CarpenterOverlayTheme - Returns the overlay theme with only the supplied semantic overlay colors replaced.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited