CarpenterRecordPage<T> class
final
Full record composition, migrated onto the current page infrastructure.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- CarpenterRecordPage
Constructors
-
CarpenterRecordPage({Key? key, required CarpenterPageDescriptor descriptor, CarpenterPageController? controller, CarpenterPageState state = const CarpenterPageReady(), Widget? header, Widget? summary, Widget? attention, List<
Widget> sections = const [], Widget? tabs, Widget? timeline, Widget? body, List<CarpenterPageCapability> capabilities = const [], List<CarpenterCommand> commands = const [], List<CarpenterCommandBinding> commandBindings = const []}) -
const
Properties
- attention → Widget?
-
final
- body → Widget?
-
final
-
capabilities
→ List<
CarpenterPageCapability> -
final
-
commandBindings
→ List<
CarpenterCommandBinding> -
final
-
commands
→ List<
CarpenterCommand> -
final
- controller → CarpenterPageController?
-
final
- descriptor → CarpenterPageDescriptor
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- header → Widget?
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
sections
→ List<
Widget> -
final
- state → CarpenterPageState
-
final
- summary → Widget?
-
final
- tabs → Widget?
-
final
- timeline → Widget?
-
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited