CarpenterReorderDetails<T> class final

Annotations

Constructors

CarpenterReorderDetails({required T item, required int oldIndex, required int targetIndex, required int newIndex, required CarpenterDropPosition position})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
item → T
final
newIndex int
final
oldIndex int
final
position CarpenterDropPosition
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
targetIndex int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited