CarpenterRouteInformationSync class final

Synchronizes yx_navigation route state with Flutter route information/history.

Mixed-in types

Constructors

CarpenterRouteInformationSync({required RouteNodeStateManager navigation, required CarpenterRouteTreeParser parse, required CarpenterRouteTreeSerializer convert, bool useMultiEntryHistory = true})
Creates a bidirectional bridge between a route-node state manager and Flutter platform history. Call attach once and dispose when its owner is torn down.

Properties

convert CarpenterRouteTreeSerializer
Serializer used when reporting navigation state back to platform history.
final
hashCode int
The hash code for this object.
no setterinherited
Navigation state manager observed for application-initiated route changes and mutated for platform-initiated route information.
final
parse CarpenterRouteTreeParser
Parser used for incoming platform URIs before mutating navigation.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
useMultiEntryHistory bool
Whether attach asks the platform to use multi-entry browser/history integration before synchronizing route changes.
final

Methods

attach() → void
Starts observing platform route information and navigation changes, reports the current state as a replacement entry, and optionally enables multi-entry history.
didChangeAccessibilityFeatures() → void
Called when the system changes the set of currently active accessibility features.
inherited
didChangeAppLifecycleState(AppLifecycleState state) → void
Called when the system puts the app in the background or returns the app to the foreground.
inherited
didChangeLocales(List<Locale>? locales) → void
Called when the system tells the app that the user's locale has changed. For example, if the user changes the system language settings.
inherited
didChangeMetrics() → void
Called when the application's dimensions change. For example, when a phone is rotated.
inherited
didChangePlatformBrightness() → void
Called when the platform brightness changes.
inherited
didChangeTextScaleFactor() → void
Called when the platform's text scale factor changes.
inherited
didChangeViewFocus(ViewFocusEvent event) → void
Called whenever the PlatformDispatcher receives a notification that the focus state on a view has changed.
inherited
didHaveMemoryPressure() → void
Called when the system is running low on memory.
inherited
didPopRoute() Future<bool>
Called when the system tells the app to pop the current route, such as after a system back button press or back gesture.
inherited
didPushRoute(String route) Future<bool>
Called when the host tells the application to push a new route onto the navigator.
inherited
didPushRouteInformation(RouteInformation routeInformation) Future<bool>
Handles platform or browser route information by parsing it, recording its canonical serialized URI, mutating navigation state, and reporting the event as handled.
override
didRequestAppExit() Future<AppExitResponse>
Called when a request is received from the system to exit the application.
inherited
dispose() Future<void>
Stops platform observation and awaits cancellation of the navigation stream subscription.
handleCancelBackGesture() → void
Called when a predictive back gesture is canceled, indicating that no navigation should occur.
inherited
handleCommitBackGesture() → void
Called when a predictive back gesture is finished successfully, indicating that the current route should be popped.
inherited
handleStartBackGesture(PredictiveBackEvent backEvent) bool
Called at the start of a predictive back gesture.
inherited
handleStatusBarTap() → void
Called when the user taps the status bar on iOS, to scroll a scroll view to the top.
inherited
handleUpdateBackGestureProgress(PredictiveBackEvent backEvent) → void
Called when a predictive back gesture moves.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

initialUri Uri
URI derived from Flutter's initial platform route name.
no setter