CarpenterShellBase class abstract

Convenience base for pass-through shells with no requirements or provided capabilities by default.

Implemented types
Implementers

Constructors

CarpenterShellBase()
Creates a pass-through shell base.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
id String
Stable shell identifier used in dependency/provision validation diagnostics.
no setterinherited
provides Set<Type>
Default empty capability provision set.
no setteroverride
requires Set<Type>
Default empty capability requirement set.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

configure(CarpenterShellConfigureContext context) CarpenterRuntime
Default configuration returns the incoming runtime unchanged.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
wrap(CarpenterShellBuildContext context, Widget child) Widget
Default wrapping returns the child unchanged.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited