CarpenterTab<T> class
final
- Annotations
Constructors
- CarpenterTab({required T value, required String label, String? semanticLabel, CarpenterIconSource? icon, bool enabled = true})
-
const
Properties
- effectiveSemanticLabel → String
-
no setter
- enabled → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- icon → CarpenterIconSource?
-
final
- label → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- semanticLabel → String?
-
final
- value → T
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited