CarpenterTimelineItem class final

Annotations

Constructors

CarpenterTimelineItem({required Object id, required String title, required DateTime timestamp, String? description, Widget? leading})
const

Properties

description String?
final
hashCode int
The hash code for this object.
no setterinherited
id Object
final
leading Widget?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timestamp DateTime
final
title String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited