CarpenterToastDescriptor class final

Annotations

Constructors

CarpenterToastDescriptor({required Object id, required String message, String? title, FeedbackColorRole role = FeedbackColorRole.info, CarpenterActionDescriptor? action, ToastDuration duration = ToastDuration.short, String dismissLabel = 'Dismiss notification'})
const

Properties

action CarpenterActionDescriptor?
final
dismissLabel String
final
duration ToastDuration
final
hashCode int
The hash code for this object.
no setterinherited
id Object
final
message String
final
role FeedbackColorRole
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited