CarpenterTreeFlatNode<T> class final

Annotations

Constructors

CarpenterTreeFlatNode({required CarpenterTreeNode<T> node, required int depth, Object? parentId})
const

Properties

depth int
final
hashCode int
The hash code for this object.
no setterinherited
node CarpenterTreeNode<T>
final
parentId Object?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited