CarpenterTreeRemoved<T> class final

Removes a loaded node and its loaded descendants from presentation data.

Inheritance

Constructors

CarpenterTreeRemoved(Object id)
Creates a removal patch for stable node id.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
id Object
Stable id of the loaded node to remove.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited