CarpenterWorkflowStage<TState, TContext> class abstract

Implementers

Constructors

CarpenterWorkflowStage({required String id, required String title, required bool when(TState state, TContext context), String? description})
const

Properties

description String?
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String
final
when bool Function(TState state, TContext context)
final

Methods

build(BuildContext context, TState state, TContext workflowContext) Widget
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited