CollectionContentState enum

Meaning of collection content, distinct from an active request or request failure.

Inheritance
Available extensions

Values

content → const CollectionContentState

The normal content presentation, including transient snapshots before a load finishes.

zero → const CollectionContentState

There are no items in the underlying collection, for example before the first record is created.

emptyResult → const CollectionContentState

The current query has no matching items, even though the underlying collection may contain data.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<CollectionContentState>
A constant List of the values in this enum, in order of their declaration.