nextKey property
K?
nextKey
final
Typed ordering key for the following page, or null when unavailable.
Implementation
final K? nextKey;
Typed ordering key for the following page, or null when unavailable.
final K? nextKey;