CollectionPageRequest class sealed

Backend-neutral pagination request carried by CollectionQuery.

Choose the subtype supported by the loader. A cursor or keyset request does not imply that an offset or total count is available.

Implementers

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited