CollectionRequestReason enum

Why a lifecycle controller invoked its loader, so adapters can choose appropriate fetching or caching behavior.

Inheritance
Available extensions

Values

initial → const CollectionRequestReason

Explicit initialization of the collection.

query → const CollectionRequestReason

Search, filter, sort, or page input changed.

refresh → const CollectionRequestReason

Explicit revalidation of the current query.

loadMore → const CollectionRequestReason

A request to extend the currently accumulated items.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<CollectionRequestReason>
A constant List of the values in this enum, in order of their declaration.