ContentColorRole enum
Semantic foreground color for non-action content.
Values
- primary → const ContentColorRole
-
Primary readable foreground for normal content.
- secondary → const ContentColorRole
-
Secondary foreground for supporting content.
- muted → const ContentColorRole
-
De-emphasized foreground for tertiary metadata or hints.
- inverse → const ContentColorRole
-
Foreground intended for use on an inverse or strongly colored surface.
- disabled → const ContentColorRole
-
Foreground communicating unavailable or disabled content.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
ContentColorRole> - A constant List of the values in this enum, in order of their declaration.