ControlSize enum
Semantic size scale used by compact controls.
Values
- xsmall → const ControlSize
-
Extra-small control size.
- small → const ControlSize
-
Small control size.
- medium → const ControlSize
-
Default medium control size.
- large → const ControlSize
-
Large control size.
- xlarge → const ControlSize
-
Extra-large control size.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
ControlSize> - A constant List of the values in this enum, in order of their declaration.