FifoDeeplinkHandlerStrategy class final
FIFO strategy: handlers are called in registration order.
- Inheritance
-
- Object
- DeeplinkHandlerStrategy
- FifoDeeplinkHandlerStrategy
Constructors
- FifoDeeplinkHandlerStrategy()
-
FIFO strategy: handlers are called in registration order.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
apply(
Iterable< DeeplinkHandler> handlers) → Iterable<DeeplinkHandler> -
Returns
handlersin the order this strategy defines.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited