GuardResultRedirect class final

Signals that the mutation should be redirected to a different target.

Implemented types

Constructors

GuardResultRedirect({required RouteNode target})
Signals that the mutation should be redirected to a different target.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
target RouteNode
The new RouteNode to navigate to instead of the proposed target.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited