InitializeSchemaNodeGuard class

Implemented types
Annotations

Constructors

InitializeSchemaNodeGuard({required YxRoute route, required InitialRouteNodeBuilder builder})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

call(RouteNode origin, RouteNode target, GuardContext context) GuardResult
Invoked when the RouteNode state is about to change.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited