LoadingController class abstract interface

UI-agnostic handle exposed to descendants through BuildContext.loading.

Implementers

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state LoadingState
Current state of this loading scope.
no setter

Methods

finish(Object id) → void
Marks id as finished. Calling this repeatedly for the same id is a no-op.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
start(Object id) → void
Marks id as active. Calling this repeatedly for the same id is a no-op.
toString() String
A string representation of this object.
inherited
track<T>(FutureOr<T> operation(), {Object? id}) Future<T>
Runs operation while this scope owns an active operation.

Operators

operator ==(Object other) bool
The equality operator.
inherited