LoadingCubit class final

Compatibility name for code written against Carpenter's former Bloc-backed loading implementation.

Inheritance
Annotations
  • @Deprecated('Use LoadingNotifier. Carpenter no longer depends on Bloc.')

Constructors

LoadingCubit()

Properties

hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
isClosed bool
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state LoadingState
Current state of this loading scope.
no setterinherited
stream Stream<LoadingState>
Compatibility stream for callers that previously listened to a Cubit.
no setterinherited
value LoadingState
The current value stored in this notifier.
getter/setter pairinherited

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
close() Future<void>
Closes compatibility streams and notifier listeners.
inherited
dispose() → void
Discards any resources used by the object.
inherited
finish(Object id) → void
Marks id as finished. Calling this repeatedly for the same id is a no-op.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
start(Object id) → void
Marks id as active. Calling this repeatedly for the same id is a no-op.
inherited
toString() String
A string representation of this object.
inherited
track<T>(FutureOr<T> operation(), {Object? id}) Future<T>
Runs operation while this scope owns an active operation.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited