OptionsLoadState enum
Loading state for option-producing controls such as selects and suggestions.
Values
- ready → const OptionsLoadState
-
Options are available and no request is currently pending.
- loading → const OptionsLoadState
-
Options are currently being loaded.
- failed → const OptionsLoadState
-
The most recent options request failed.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
OptionsLoadState> - A constant List of the values in this enum, in order of their declaration.