OverlayPlacement enum

Preferred placement of anchored overlay content relative to its anchor.

Inheritance
Available extensions

Values

top → const OverlayPlacement

Centered above the anchor.

bottom → const OverlayPlacement

Centered below the anchor.

left → const OverlayPlacement

Centered to the left of the anchor.

Centered to the right of the anchor.

topStart → const OverlayPlacement

Above the anchor aligned to its directional start edge.

topEnd → const OverlayPlacement

Above the anchor aligned to its directional end edge.

bottomStart → const OverlayPlacement

Below the anchor aligned to its directional start edge.

bottomEnd → const OverlayPlacement

Below the anchor aligned to its directional end edge.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<OverlayPlacement>
A constant List of the values in this enum, in order of their declaration.