PaletteTokens class final

Constructors

PaletteTokens()
const

Properties

black Color
no setter
brand → PaletteBrandTokens
final
danger → PaletteDangerTokens
final
hashCode int
The hash code for this object.
no setterinherited
info → PaletteInfoTokens
final
neutral → PaletteNeutralTokens
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secondary → PaletteSecondaryTokens
final
success → PaletteSuccessTokens
final
transparent Color
no setter
utility → PaletteUtilityTokens
final
warning → PaletteWarningTokens
final
white Color
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited