PushRouteMutationCallback typedef
Signature for a callback invoked when a route is pushed onto the tree.
Implementation
@experimental
typedef PushRouteMutationCallback = void Function(
RouteNode origin,
RouteNode target,
);
Signature for a callback invoked when a route is pushed onto the tree.
@experimental
typedef PushRouteMutationCallback = void Function(
RouteNode origin,
RouteNode target,
);