Radians class final

An angle expressed in radians.

Inheritance

Constructors

Radians(double value)
Creates a radian value.
const

Properties

canonical String
A deterministic authoring representation of this unit.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
symbol String
The canonical suffix for this unit.
no setteroverride
value double
Numeric magnitude of this unit.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDegrees() Degrees
Converts this angle to degrees.
override
toRadians() Radians
Converts this angle to radians.
override
toString() String
A string representation of this object.
inherited
toTurns() Turns
Converts this angle to turns.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited