key constant
String
const key
Key used to store the redirect counter in the guard context.
Implementation
static const String key = '_redirect_count_key';
Key used to store the redirect counter in the guard context.
static const String key = '_redirect_count_key';