SquidPathBasedSerializer class abstract

Path-based serializer for navigation state.

Serializes RouteNode tree to URL path (without #).

Example: /root/.child1/..child2

This is useful for scenarios where third parties ignore the hash (#) in redirect URLs, such as OAuth callbacks or Telegram login redirects.

See also:

Constructors

SquidPathBasedSerializer()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromUri(Uri uri) RouteNode
Parses uri's path back into a RouteNode tree.
toUri(RouteNode node) Uri
Encodes node as a Uri whose path describes the tree.

Constants

prefix → const String