TypographyRole enum

Semantic typography family chosen independently from emphasis and color.

Inheritance
Available extensions

Values

display → const TypographyRole

Largest editorial or hero text intended for rare, high-priority headings.

title → const TypographyRole

Section, page, or component heading text.

body → const TypographyRole

Default prose and control-supporting text.

label → const TypographyRole

Compact text used for field labels, controls, and terse metadata.

caption → const TypographyRole

Small supporting or secondary annotation text.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<TypographyRole>
A constant List of the values in this enum, in order of their declaration.