Unit class sealed

A typed physical UI quantity.

Properties

canonical String
A deterministic authoring representation of this unit.
no setter
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
symbol String
The canonical suffix for this unit.
no setter
value double
Numeric magnitude of this unit.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

parse(String source) Unit
Parses a physical unit from its authoring representation.
tryParse(String source) Unit?
Parses a physical unit, or returns null when source is not one.