UpdateRouteMutationCallback typedef
Signature for a callback invoked when an existing route is updated.
Implementation
@experimental
typedef UpdateRouteMutationCallback = void Function(
RouteNode origin,
RouteNode target,
);
Signature for a callback invoked when an existing route is updated.
@experimental
typedef UpdateRouteMutationCallback = void Function(
RouteNode origin,
RouteNode target,
);