Carpenter class
Visual runtime Carpenter.
Carpenter собирается из CarpenterConfig и вычисляет визуальный язык
приложения. Компоненты не должны обращаться к runtime напрямую: для них
публичной поверхностью является context.face.
Constructors
- Carpenter.fromConfig(CarpenterConfig config)
- Создает runtime из декларативного конфига.
Properties
- config → CarpenterConfig
-
Исходная декларация visual runtime.
final
- face → CarpenterFace
-
Фасад визуального языка, который читают компоненты.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- theme → CarpenterFace
-
Совместимость со старым именем до введения
Face.no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rem(
double value) → double - Возвращает размер в физических пикселях из rem-единиц.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited