CarpenterAppFrame class

Кроссплатформенный каркас приложения Carpenter.

CarpenterAppFrame позволяет заменить верхнюю панель на desktop через desktopTopPanelBuilder, сохранив обычную cross-platform сборку на остальных платформах. Компонент не управляет нативным window chrome напрямую: скрытие системной рамки, если оно нужно, остается задачей runner или window-plugin.

Inheritance

Constructors

CarpenterAppFrame({Key? key, required Widget child, CarpenterTopPanelBuilder? topPanelBuilder, CarpenterTopPanelBuilder? desktopTopPanelBuilder, TargetPlatform? targetPlatform, bool useSafeArea = true, EdgeInsetsGeometry? padding, Color? backgroundColor})
Создает app-frame.
const

Properties

backgroundColor Color?
Фон app-frame. Если не задан, берется face.color('surface.base').
final
child Widget
Основное содержимое приложения.
final
desktopTopPanelBuilder CarpenterTopPanelBuilder?
Desktop-панель, которая переопределяет topPanelBuilder на desktop.
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
padding EdgeInsetsGeometry?
Отступ вокруг всего app-frame.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
targetPlatform TargetPlatform?
Platform override для тестов и preview.
final
topPanelBuilder CarpenterTopPanelBuilder?
Панель по умолчанию для всех платформ.
final
useSafeArea bool
Оборачивать содержимое в SafeArea.
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited