CarpenterAsyncSearchField<T> class
Complete searchable suggestion field.
Carpenter owns text synchronization, debounce, cancellation, stale-result protection, loading, errors and suggestion layout. A domain module only supplies the loader and how one result is described.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- CarpenterAsyncSearchField
Constructors
-
CarpenterAsyncSearchField({Key? key, required CarpenterSuggestionLoader<
T> load, required String title(T item), required ValueChanged<T?> onSelected, String subtitle(T item)?, Object? selected, String? selectedLabel, ValueChanged<String> ? onQueryChanged, String? placeholder, String? error, Duration debounce = const Duration(milliseconds: 300), int minimumQueryLength = 1, double maxSuggestionHeight = 240}) -
const
Properties
- debounce → Duration
-
final
- error → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
-
load
→ CarpenterSuggestionLoader<
T> -
final
- maxSuggestionHeight → double
-
final
- minimumQueryLength → int
-
final
-
onQueryChanged
→ ValueChanged<
String> ? -
final
-
onSelected
→ ValueChanged<
T?> -
final
- placeholder → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selected → Object?
-
final
- selectedLabel → String?
-
final
- subtitle → String Function(T item)?
-
final
- title → String Function(T item)
-
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< CarpenterAsyncSearchField< T> > -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited