CarpenterCollectionDialog<T, TFilter, TSort> class
Complete collection picker dialog with standard query, state, scrolling, empty/error presentation and actions.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- CarpenterCollectionDialog
Constructors
-
CarpenterCollectionDialog({Key? key, required Widget title, required CarpenterDataCollectionControllerBase<
T, TFilter, TSort> controller, required Object itemIdentity(T item), required CarpenterDataCollectionItemBuilder<T> itemBuilder, List<CarpenterDataGroup< groupBy(List<T> >T> items)?, ValueChanged<T> ? onItemActivate, String? queryPlaceholder, CarpenterEmptyStateDescriptor? empty, CarpenterEmptyStateDescriptor? filteredEmpty, List<Widget> actions = const [], BoxConstraints constraints = const BoxConstraints(maxWidth: 760, maxHeight: 650)}) -
const
Properties
-
actions
→ List<
Widget> -
final
- constraints → BoxConstraints
-
final
-
controller
→ CarpenterDataCollectionControllerBase<
T, TFilter, TSort> -
final
- empty → CarpenterEmptyStateDescriptor?
-
final
- filteredEmpty → CarpenterEmptyStateDescriptor?
-
final
-
groupBy
→ List<
CarpenterDataGroup< Function(List<T> >T> items)? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
itemBuilder
→ CarpenterDataCollectionItemBuilder<
T> -
final
- itemIdentity → Object Function(T item)
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
-
onItemActivate
→ ValueChanged<
T> ? -
final
- queryPlaceholder → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title → Widget
-
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited