CarpenterCollectionFailure<T> class final

Inheritance

Constructors

CarpenterCollectionFailure({required Object error, String? message})
const

Properties

error Object
final
hashCode int
The hash code for this object.
no setterinherited
message String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
visibleItems List<T>
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited