CarpenterCollectionPartialFailure<T> class
final
- Inheritance
-
- Object
- CarpenterCollectionState<
T> - CarpenterCollectionPartialFailure
Constructors
-
CarpenterCollectionPartialFailure({required List<
T> items, required Object error}) -
const
Properties
- error → Object
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
items
→ List<
T> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
visibleItems
→ List<
T> -
no setteroverride
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited