CarpenterCollectionQuery<TFilter, TSort> class final

Constructors

CarpenterCollectionQuery({required String search, required TFilter filter, required TSort sort})
const

Properties

filter → TFilter
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
final
sort → TSort
final

Methods

copyWith({String? search, TFilter? filter, TSort? sort}) CarpenterCollectionQuery<TFilter, TSort>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited