CarpenterCollectionReady<T> class final

Inheritance

Constructors

CarpenterCollectionReady({required List<T> items, bool refreshing = false, bool hasNextPage = false, int page = 1, int totalPages = 1, int? totalItems})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
hasNextPage bool
final
items List<T>
final
page int
final
refreshing bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalItems int?
final
totalPages int
final
visibleItems List<T>
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited