CarpenterColor class

Dynamic semantic colors visual runtime.

Constructors

CarpenterColor({required CarpenterPalette palette, required Map<String, Color> tokens})
Создает semantic color registry.
const
CarpenterColor.fromConfig({required CarpenterColorConfig config, required CarpenterPaletteConfig fallbackPalette, required Brightness brightness})
Собирает color runtime из config.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
palette CarpenterPalette
Primitive palette runtime.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tokens Map<String, Color>
Dynamic semantic registry.
final

Methods

call(String role) Color
Возвращает semantic color по роли.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited
operator [](String role) Color
Возвращает semantic color по роли.