CarpenterColorConfig class

Настройка color runtime.

Цвета Carpenter полностью dynamic: palette scales, palette steps и semantic roles расширяемы без изменения классов Carpenter.

Constructors

CarpenterColorConfig({CarpenterPaletteConfig? palette, Map<String, Color> semantic = const {}, CarpenterSemanticColorResolver? semanticResolver})
Создает настройку color runtime.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
palette CarpenterPaletteConfig?
Настройка primitive palette.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
semantic Map<String, Color>
Явные semantic colors или partial overrides.
final
semanticResolver CarpenterSemanticColorResolver?
Resolver semantic roles из palette.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited