CarpenterColorScale class

Dynamic цветовая шкала с произвольными шагами.

Constructors

CarpenterColorScale(Map<String, Color> colors)
Создает шкалу из dynamic registry цветов.
const
CarpenterColorScale.fromConfig(CarpenterColorScaleConfig config)
Создает шкалу из config.
factory

Properties

colors Map<String, Color>
Dynamic registry цветов.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

call(Object step) Color
Возвращает цвет по любому шагу.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited
operator [](Object step) Color
Возвращает цвет по любому шагу.