CarpenterCommand<I> class abstract interface

Implementers
Available extensions

Properties

androidShortcuts List<ShortcutActivator>?
no setter
description String?
no setter
effects List<CarpenterCommandEffect>
no setter
fuchsiaShortcuts List<ShortcutActivator>?
no setter
group String
no setter
hashCode int
The hash code for this object.
no setterinherited
id String
no setter
iOSShortcuts List<ShortcutActivator>?
no setter
linuxShortcuts List<ShortcutActivator>?
no setter
macOSShortcuts List<ShortcutActivator>?
no setter
presentation CarpenterCommandPresentation
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shortcuts List<ShortcutActivator>
no setter
state ValueListenable<CarpenterCommandState>
no setter
title String
no setter
windowsShortcuts List<ShortcutActivator>?
no setter

Methods

activatorsFor(TargetPlatform platform) List<ShortcutActivator>

Available on CarpenterCommand, provided by the CarpenterCommandPlatformShortcuts extension

Compatibility spelling retained during the command-model migration.
execute(I input) Future<CarpenterCommandResult>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shortcutsFor(TargetPlatform platform) List<ShortcutActivator>

Available on CarpenterCommand, provided by the CarpenterCommandPlatformShortcuts extension

Returns the command shortcuts resolved for one target platform.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited