CarpenterCommandController<I> class

Inheritance
Implemented types
Available extensions

Constructors

CarpenterCommandController({required String id, required String title, FutureOr<CarpenterCommandResult> execute(I input)?, String group = 'General', String? description, List<ShortcutActivator> shortcuts = const [], List<ShortcutActivator>? activators, List<ShortcutActivator>? macOSShortcuts, List<ShortcutActivator>? macOSActivators, List<ShortcutActivator>? windowsShortcuts, List<ShortcutActivator>? windowsActivators, List<ShortcutActivator>? linuxShortcuts, List<ShortcutActivator>? linuxActivators, List<ShortcutActivator>? iOSShortcuts, List<ShortcutActivator>? iOSActivators, List<ShortcutActivator>? androidShortcuts, List<ShortcutActivator>? androidActivators, List<ShortcutActivator>? fuchsiaShortcuts, List<ShortcutActivator>? fuchsiaActivators, CarpenterCommandPresentation presentation = CarpenterCommandPresentation.automatic, List<CarpenterCommandEffect> effects = const [], CarpenterCommandState initialState = const CarpenterCommandState()})

Properties

androidShortcuts List<ShortcutActivator>?
final
description String?
final
effects List<CarpenterCommandEffect>
final
fuchsiaShortcuts List<ShortcutActivator>?
final
group String
final
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
id String
final
iOSShortcuts List<ShortcutActivator>?
final
linuxShortcuts List<ShortcutActivator>?
final
macOSShortcuts List<ShortcutActivator>?
final
presentation CarpenterCommandPresentation
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shortcuts List<ShortcutActivator>
final
state ValueListenable<CarpenterCommandState>
no setteroverride
title String
final
value CarpenterCommandState
The current value stored in this notifier.
getter/setter pairinherited
windowsShortcuts List<ShortcutActivator>?
final

Methods

activatorsFor(TargetPlatform platform) List<ShortcutActivator>

Available on CarpenterCommand, provided by the CarpenterCommandPlatformShortcuts extension

Compatibility spelling retained during the command-model migration.
addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
dispose() → void
Discards any resources used by the object.
inherited
execute(I input) Future<CarpenterCommandResult>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
setAvailability({CarpenterCommandVisibility visibility = CarpenterCommandVisibility.visible, required bool enabled, String? disabledReason}) → void
shortcutsFor(TargetPlatform platform) List<ShortcutActivator>

Available on CarpenterCommand, provided by the CarpenterCommandPlatformShortcuts extension

Returns the command shortcuts resolved for one target platform.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited