CarpenterCommandResult class

Constructors

CarpenterCommandResult({String? message, FutureOr<void> undo()?, Set<String> refreshScopes = const {}, bool blockingEffect = false})
const

Properties

blockingEffect bool
final
hashCode int
The hash code for this object.
no setterinherited
message String?
final
refreshScopes Set<String>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
undo FutureOr<void> Function()?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited