CarpenterCommandState class

Constructors

CarpenterCommandState({CarpenterCommandVisibility visibility = CarpenterCommandVisibility.visible, bool enabled = true, String? disabledReason, CarpenterCommandExecution execution = CarpenterCommandExecution.idle, Object? error})
const

Properties

disabledReason String?
final
enabled bool
final
error Object?
final
execution CarpenterCommandExecution
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
visibility CarpenterCommandVisibility
final

Methods

copyWith({CarpenterCommandVisibility? visibility, bool? enabled, String? disabledReason, CarpenterCommandExecution? execution, Object? error, bool clearError = false}) CarpenterCommandState
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited