CarpenterCoreRuntime class

Core capability Carpenter-приложения.

Constructors

CarpenterCoreRuntime({required Carpenter carpenter, required TargetPlatform platform, Locale? locale})
Создает core runtime capability.
const

Properties

carpenter Carpenter
Visual runtime.
final
hashCode int
The hash code for this object.
no setterinherited
locale Locale?
Локаль приложения.
final
platform TargetPlatform
Target platform приложения.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited