CarpenterDimension class

Dynamic dimension visual runtime.

Constructors

CarpenterDimension({required double remBase, required double density, required Map<String, double> spaceTokens, required Map<String, double> radiusTokens, required Map<String, double> sizeTokens, required Map<String, double> tokens})
Создает dimension registry.
const
CarpenterDimension.fromConfig(CarpenterDimensionConfig config)
Создает dimension runtime из config.
factory

Properties

density double
Плотность интерфейса.
final
hashCode int
The hash code for this object.
no setterinherited
radiusTokens Map<String, double>
Dynamic radius registry.
final
remBase double
Базовая rem-единица.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sizeTokens Map<String, double>
Dynamic size registry.
final
spaceTokens Map<String, double>
Dynamic space registry.
final
tokens Map<String, double>
Dynamic arbitrary dimension registry.
final

Methods

call(String role) double
Возвращает произвольный dimension token.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
radius(String role) double
Возвращает radius token.
rem(double value) double
Возвращает размер из rem-единиц.
size(String role) double
Возвращает size token.
space(String role) double
Возвращает space token.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited