CarpenterDropCapability<T> class final

Implemented types

Constructors

CarpenterDropCapability({required bool canAccept(T data), required Future<void> execute(T data), Widget previewBuilder(BuildContext context, T data)?})
const

Properties

canAccept bool Function(T data)
final
execute Future<void> Function(T data)
final
hashCode int
The hash code for this object.
no setterinherited
previewBuilder Widget Function(BuildContext context, T data)?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited