CarpenterEmptyStateDescriptor class final
Constructors
-
CarpenterEmptyStateDescriptor({required String title, String? message, CarpenterEmptyStateKind kind = CarpenterEmptyStateKind.collection, CarpenterCommand<
void> ? action}) -
const
Properties
-
action
→ CarpenterCommand<
void> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- kind → CarpenterEmptyStateKind
-
final
- message → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited