CarpenterFrameRuntime class
Runtime capability app-frame shell-а.
Constructors
- CarpenterFrameRuntime({required TargetPlatform platform})
-
Создает frame runtime.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- platform → TargetPlatform
-
Target platform frame-а.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited