CarpenterFrameShell class

Shell, который подключает CarpenterAppFrame.

Inheritance

Constructors

CarpenterFrameShell({CarpenterTopPanelBuilder? topPanelBuilder, CarpenterTopPanelBuilder? desktopTopPanelBuilder, TargetPlatform? targetPlatform, bool useSafeArea = true, EdgeInsetsGeometry? padding, Color? backgroundColor})
Создает frame shell.
const

Properties

backgroundColor Color?
Фон frame.
final
desktopTopPanelBuilder CarpenterTopPanelBuilder?
Desktop-override верхней панели.
final
hashCode int
The hash code for this object.
no setterinherited
id String
Стабильный id shell-а для диагностики.
no setteroverride
padding EdgeInsetsGeometry?
Отступ frame.
final
provides Set<Type>
Capabilities, которые shell обещает добавить.
no setteroverride
requires Set<Type>
Capabilities, которые должны существовать до этого shell-а.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
targetPlatform TargetPlatform?
Platform override.
final
topPanelBuilder CarpenterTopPanelBuilder?
Верхняя панель по умолчанию.
final
useSafeArea bool
Использовать SafeArea.
final

Methods

configure(CarpenterShellConfigureContext context) CarpenterRuntime
Расширяет runtime. Вызывается слева направо по списку shell-ов.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
wrap(CarpenterShellBuildContext context, Widget child) Widget
Оборачивает widget tree. Визуально shell-и применяются как middleware.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited