CarpenterHotkeyRuntime class
Runtime capability hotkey shell-а.
Constructors
-
CarpenterHotkeyRuntime({required CarpenterHotkeyController controller, required List<
CarpenterCommand< commands})void> > -
Создает hotkey runtime.
const
Properties
-
commands
→ List<
CarpenterCommand< void> > -
Зарегистрированные команды.
final
- controller → CarpenterHotkeyController
-
Контроллер текущего состояния клавиатуры.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited