CarpenterHotkeyShell class

Shell, который подключает CarpenterHotkeyScope и capability hotkeys.

Inheritance

Constructors

CarpenterHotkeyShell({List<CarpenterCommand<void>> commands = const [], CarpenterRuntimeHotkeyCommandCallback? onCommand, CarpenterHotkeyController? controller, bool enabled = true, bool trackPressedKeys = true, bool autofocus = true, TargetPlatform? platform})
Создает hotkey shell.

Properties

autofocus bool
Автофокус hotkey-ветки.
final
commands List<CarpenterCommand<void>>
Hotkey-команды.
final
controller CarpenterHotkeyController
Контроллер hotkey state.
final
enabled bool
Включить shortcuts и мониторинг.
final
hashCode int
The hash code for this object.
no setterinherited
id String
Стабильный id shell-а для диагностики.
no setteroverride
onCommand CarpenterRuntimeHotkeyCommandCallback?
Callback выполнения команды с доступом к runtime.
final
platform TargetPlatform?
Platform override для выбора hotkey-комбинаций.
final
provides Set<Type>
Capabilities, которые shell обещает добавить.
no setteroverride
requires Set<Type>
Capabilities, которые должны существовать до этого shell-а.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
trackPressedKeys bool
Отслеживать текущие нажатые клавиши.
final

Methods

configure(CarpenterShellConfigureContext context) CarpenterRuntime
Расширяет runtime. Вызывается слева направо по списку shell-ов.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
wrap(CarpenterShellBuildContext context, Widget child) Widget
Оборачивает widget tree. Визуально shell-и применяются как middleware.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited