CarpenterInput class

Текстовое поле Carpenter.

CarpenterInput является controlled/uncontrolled field-компонентом. Если передан controller, состояние текста хранит внешний код. Если controller не передан, компонент создает внутренний TextEditingController.

Inheritance

Constructors

CarpenterInput({Key? key, TextEditingController? controller, String? initialValue, FocusNode? focusNode, String? label, String? placeholder, Widget? prefix, Widget? suffix, String? errorText, bool enabled = true, ValueChanged<String>? onChanged, TextInputType? keyboardType, List<TextInputFormatter>? inputFormatters, int? maxLines = 1, TextCapitalization textCapitalization = TextCapitalization.none, ValueChanged<String>? onSubmitted, bool obscureText = false, String obscuringCharacter = '•'})
Создает текстовое поле.
const

Properties

controller TextEditingController?
Внешний controller текста.
final
enabled bool
Доступность поля.
final
errorText String?
Текст ошибки под полем.
final
focusNode FocusNode?
Внешний focus node.
final
hashCode int
The hash code for this object.
no setterinherited
initialValue String?
Начальное значение для внутреннего controller.
final
inputFormatters List<TextInputFormatter>?
Форматтеры ввода.
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
keyboardType TextInputType?
Тип клавиатуры.
final
label String?
Подпись поля.
final
maxLines int?
Максимальное количество строк.
final
obscureText bool
Скрывает ввод, например для пароля.
final
obscuringCharacter String
Символ, которым заменяются скрытые знаки.
final
onChanged ValueChanged<String>?
Обработчик изменения текста.
final
onSubmitted ValueChanged<String>?
final
placeholder String?
Placeholder внутри пустого поля.
final
prefix Widget?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
suffix Widget?
final
textCapitalization TextCapitalization
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<CarpenterInput>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited