CarpenterModuleBase class abstract

Удобная база для модулей.

Implemented types

Constructors

CarpenterModuleBase()
Создает base module.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
id String
Стабильный id модуля.
no setterinherited
provides Set<Type>
Capabilities, которые модуль обещает предоставить своими shell-ами.
no setteroverride
requires Set<Type>
Capabilities, которые нужны модулю на app-level.
no setteroverride
routes List<CarpenterRoute>
Root routes модуля.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shells List<CarpenterShell>
Shell-и модуля.
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited