CarpenterPageController class abstract interface

Coordinates page infrastructure while domain state stays in domain code.

Implemented types
Implementers

Properties

hashCode int
The hash code for this object.
no setterinherited
pageCommands List<CarpenterCommand>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value CarpenterPageState
The current value of the object.
no setterinherited

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object notifies its listeners.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
refresh() Future<void>
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that the object notifies.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited