CarpenterPageDescriptor class final

Compact, immutable metadata shared by the page infrastructure.

Constructors

CarpenterPageDescriptor({required CarpenterPageId id, required String title, required CarpenterPageKind kind, CarpenterRestorationPolicy? restorationPolicy, CarpenterPermissionRequirement? permission})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
id CarpenterPageId
final
kind CarpenterPageKind
final
permission CarpenterPermissionRequirement?
final
restorationPolicy CarpenterRestorationPolicy?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited