CarpenterPageFailure class final
- Inheritance
-
- Object
- CarpenterPageState
- CarpenterPageFailure
Constructors
-
CarpenterPageFailure({required Object error, String? message, CarpenterCommand<
void> ? retryCommand}) -
const
Properties
- error → Object
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String?
-
final
-
retryCommand
→ CarpenterCommand<
void> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited