CarpenterResourceController<T> class

Owns the complete lifecycle of one asynchronously loaded record/resource.

Inheritance
Implemented types

Constructors

CarpenterResourceController({required CarpenterResourceLoader<T> load, String errorMessage(Object error)?})

Properties

data ↔ T?
getter/setter pair
errorMessage String Function(Object error)?
final
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
pageCommands List<CarpenterCommand>
no setteroverride
refreshCommand CarpenterCommandController<void>
latefinal
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value CarpenterPageState
The current value stored in this notifier.
getter/setter pairinherited

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
dispose() → void
Discards any resources used by the object.
override
initialize() Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
refresh() Future<void>
override
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
reportFailure(Object error) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited