CarpenterRestorationKey<T> class
final
A typed key within a page restoration namespace.
Constructors
- CarpenterRestorationKey({required CarpenterPageId pageId, required String name})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- name → String
-
final
- pageId → CarpenterPageId
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- storageKey → String
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override