- Implementers
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
read<
T> (CarpenterRestorationKey< T> key) → Future<T?> -
remove(
CarpenterRestorationKey< Object?> key) → Future<void> -
toString(
) → String -
A string representation of this object.
inherited
-
write<
T> (CarpenterRestorationKey< T> key, T value) → Future<void>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited