CarpenterRouteContext class
Контекст route builder-ов Carpenter.
Constructors
-
CarpenterRouteContext({required CarpenterRuntime runtime, required CarpenterRouteMatch match, required List<
CarpenterRouteMatch> chain}) -
Создает route context.
const
Properties
-
arguments
→ Map<
String, String> -
Serializable arguments route node.
no setter
-
chain
→ List<
CarpenterRouteMatch> -
Вся active chain от root до terminal page.
final
-
extra
→ Map<
String, Object?> -
Runtime-only payload route node.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- match → CarpenterRouteMatch
-
Текущий match.
final
- node → RouteNode
-
Route node из yx_navigation.
no setter
- route → CarpenterRoute
-
Route declaration.
no setter
- runtime → CarpenterRuntime
-
Typed runtime registry текущего приложения.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited