CarpenterRouterShell class

Shell, который подключает yx_navigation к runtime Carpenter.

yx_navigation остается источником navigation state, а Carpenter только слушает RouteNode и рендерит соответствующее дерево widgets.

Inheritance

Constructors

CarpenterRouterShell({required NavigationController navigation})
Создает router shell.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
id String
Стабильный id shell-а для диагностики.
no setteroverride
Navigation controller/state manager из yx_navigation.
final
provides Set<Type>
Capabilities, которые shell обещает добавить.
no setteroverride
requires Set<Type>
Capabilities, которые должны существовать до этого shell-а.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

configure(CarpenterShellConfigureContext context) CarpenterRuntime
Расширяет runtime. Вызывается слева направо по списку shell-ов.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
wrap(CarpenterShellBuildContext context, Widget child) Widget
Оборачивает widget tree. Визуально shell-и применяются как middleware.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited