CarpenterSegmentedOption<T> class

Одна опция segmented radio.

Constructors

CarpenterSegmentedOption({required T value, required String label, String? semanticLabel})
Создает опцию segmented radio.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
label String
Видимая подпись опции.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
semanticLabel String?
Accessibility-подпись, если она отличается от видимой.
final
value → T
Значение опции.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited