CarpenterSelectionWorkflowStage<TState, TContext, TItem> class

A workflow stage for choosing exactly one domain item.

Inheritance

Constructors

CarpenterSelectionWorkflowStage({required String id, required String title, required bool when(TState state, TContext context), required List<TItem> items(TState state, TContext context), required Object identity(TItem item), required Object? selectedIdentity(TState state, TContext context), required ValueChanged<TItem> onSelected, required Widget itemBuilder(BuildContext context, TItem item, bool selected, VoidCallback select), String emptyMessage = 'Нет доступных вариантов', String? description})
const

Properties

description String?
finalinherited
emptyMessage String
final
hashCode int
The hash code for this object.
no setterinherited
id String
finalinherited
identity Object Function(TItem item)
final
itemBuilder Widget Function(BuildContext context, TItem item, bool selected, VoidCallback select)
final
items List<TItem> Function(TState state, TContext context)
final
onSelected ValueChanged<TItem>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedIdentity Object? Function(TState state, TContext context)
final
title String
finalinherited
when bool Function(TState state, TContext context)
finalinherited

Methods

build(BuildContext context, TState state, TContext workflowContext) Widget
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited