CarpenterShell class abstract interface

Middleware-like shell Carpenter.

Shell может объявить capabilities, которые он предоставляет и требует, расширить typed runtime registry и обернуть дочернее дерево widgets.

Implementers

Properties

hashCode int
The hash code for this object.
no setterinherited
id String
Стабильный id shell-а для диагностики.
no setter
provides Set<Type>
Capabilities, которые shell обещает добавить.
no setter
requires Set<Type>
Capabilities, которые должны существовать до этого shell-а.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

configure(CarpenterShellConfigureContext context) CarpenterRuntime
Расширяет runtime. Вызывается слева направо по списку shell-ов.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
wrap(CarpenterShellBuildContext context, Widget child) Widget
Оборачивает widget tree. Визуально shell-и применяются как middleware.

Operators

operator ==(Object other) bool
The equality operator.
inherited