CarpenterTable<T> class
final
A declarative, client-side data table with configurable columns, search, per-column value filters and stable sorting.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- CarpenterTable
Constructors
-
CarpenterTable({Key? key, required List<
T> items, required List<CarpenterTableColumn< columns, String? initialSortColumnId, bool initialSortAscending = true, String searchPlaceholder = 'Поиск по таблице', String emptyMessage = 'Строки не найдены', ValueChanged<T> >T> ? onRowActivate, Object rowIdentity(T item)?, bool showToolbar = true, double rowHeight = 42, double headerHeight = 40, double? maxBodyHeight}) -
const
Properties
-
columns
→ List<
CarpenterTableColumn< T> > -
final
- emptyMessage → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- headerHeight → double
-
final
- initialSortAscending → bool
-
final
- initialSortColumnId → String?
-
final
-
items
→ List<
T> -
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- maxBodyHeight → double?
-
final
-
onRowActivate
→ ValueChanged<
T> ? -
final
- rowHeight → double
-
final
- rowIdentity → Object Function(T item)?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- searchPlaceholder → String
-
final
- showToolbar → bool
-
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< CarpenterTable< T> > -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited