CarpenterTableColumn<T> class final

Constructors

CarpenterTableColumn({required String id, required String label, required CarpenterTableValue<T> value, CarpenterTableCellBuilder<T>? cell, CarpenterTableValue<T>? filterValue, double width = 160, bool sortable = true, bool searchable = true, bool filterable = false, Alignment align = Alignment.centerLeft})
const

Properties

align Alignment
final
cell CarpenterTableCellBuilder<T>?
final
filterable bool
final
filterValue CarpenterTableValue<T>?
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
label String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
searchable bool
final
sortable bool
final
value CarpenterTableValue<T>
final
width double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited