CarpenterText constructor
const
CarpenterText(
- String data, {
- Key? key,
- TextStyle? style,
- StrutStyle? strutStyle,
- TextAlign? textAlign,
- TextDirection? textDirection,
- Locale? locale,
- bool? softWrap,
- TextOverflow? overflow,
- @Deprecated('Use textScaler instead. ' 'Use of textScaleFactor was deprecated in preparation for the upcoming ' 'nonlinear text scaling support.') double? textScaleFactor,
- TextScaler? textScaler,
- int? maxLines,
- String? semanticsLabel,
- String? semanticsIdentifier,
- TextWidthBasis? textWidthBasis,
- TextHeightBehavior? textHeightBehavior,
- Color? selectionColor,
- CarpenterTextVariant variant = CarpenterTextVariant.body,
- CarpenterTextTone tone = CarpenterTextTone.primary,
Создает текстовый primitive из строки.
Implementation
const CarpenterText(
super.data, {
super.key,
super.style,
super.strutStyle,
super.textAlign,
super.textDirection,
super.locale,
super.softWrap,
super.overflow,
@Deprecated(
'Use textScaler instead. '
'Use of textScaleFactor was deprecated in preparation for the upcoming '
'nonlinear text scaling support.',
)
super.textScaleFactor,
super.textScaler,
super.maxLines,
super.semanticsLabel,
super.semanticsIdentifier,
super.textWidthBasis,
super.textHeightBehavior,
super.selectionColor,
this.variant = CarpenterTextVariant.body,
this.tone = CarpenterTextTone.primary,
});