CarpenterText.rich constructor

const CarpenterText.rich(
  1. InlineSpan textSpan, {
  2. Key? key,
  3. TextStyle? style,
  4. StrutStyle? strutStyle,
  5. TextAlign? textAlign,
  6. TextDirection? textDirection,
  7. Locale? locale,
  8. bool? softWrap,
  9. TextOverflow? overflow,
  10. @Deprecated('Use textScaler instead. ' 'Use of textScaleFactor was deprecated in preparation for the upcoming ' 'nonlinear text scaling support.') double? textScaleFactor,
  11. TextScaler? textScaler,
  12. int? maxLines,
  13. String? semanticsLabel,
  14. String? semanticsIdentifier,
  15. TextWidthBasis? textWidthBasis,
  16. TextHeightBehavior? textHeightBehavior,
  17. Color? selectionColor,
  18. CarpenterTextVariant variant = CarpenterTextVariant.body,
  19. CarpenterTextTone tone = CarpenterTextTone.primary,
})

Создает текстовый primitive из widgets.InlineSpan.

Implementation

const CarpenterText.rich(
  super.textSpan, {
  super.key,
  super.style,
  super.strutStyle,
  super.textAlign,
  super.textDirection,
  super.locale,
  super.softWrap,
  super.overflow,
  @Deprecated(
    'Use textScaler instead. '
    'Use of textScaleFactor was deprecated in preparation for the upcoming '
    'nonlinear text scaling support.',
  )
  super.textScaleFactor,
  super.textScaler,
  super.maxLines,
  super.semanticsLabel,
  super.semanticsIdentifier,
  super.textWidthBasis,
  super.textHeightBehavior,
  super.selectionColor,
  this.variant = CarpenterTextVariant.body,
  this.tone = CarpenterTextTone.primary,
}) : super.rich();