CarpenterTextFieldDescriptor class final

Constructors

CarpenterTextFieldDescriptor({required String id, required String label, String? initialValue, String? placeholder, int maxLines = 1})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
id String
final
initialValue String?
final
label String
final
maxLines int
final
placeholder String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited