CarpenterTextVariant enum

Роль текста в визуальном языке Carpenter.

Inheritance
Available extensions

Values

title → const CarpenterTextVariant

Заголовок первого уровня.

subtitle → const CarpenterTextVariant

Заголовок второго уровня.

body → const CarpenterTextVariant

Основной текст.

bodyStrong → const CarpenterTextVariant

Основной текст с усиленной важностью.

label → const CarpenterTextVariant

Подпись control или компактного элемента.

labelStrong → const CarpenterTextVariant

Усиленная подпись control или компактного элемента.

labelPrimary → const CarpenterTextVariant

Подпись control в основном шрифте.

labelPrimaryStrong → const CarpenterTextVariant

Усиленная подпись control в основном шрифте.

caption → const CarpenterTextVariant

Второстепенный мелкий текст.

captionPrimary → const CarpenterTextVariant

Второстепенный мелкий текст в основном шрифте.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<CarpenterTextVariant>
A constant List of the values in this enum, in order of their declaration.