CarpenterTopPanel class

Верхняя панель приложения Carpenter.

Это обычный widgets.dart компонент: его можно использовать как дефолтную панель или как основу для desktop override внутри CarpenterAppFrame.

Inheritance

Constructors

CarpenterTopPanel({Key? key, String? title, String? subtitle, Widget? leading, List<Widget> actions = const [], Widget? child, double? height, EdgeInsetsGeometry? padding, bool showDivider = true})
Создает верхнюю панель.
const

Properties

actions List<Widget>
Виджеты справа.
final
child Widget?
Полностью кастомное содержимое панели.
final
hashCode int
The hash code for this object.
no setterinherited
height double?
Высота панели.
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
leading Widget?
Виджет слева от заголовка.
final
padding EdgeInsetsGeometry?
Внутренние отступы панели.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showDivider bool
Показывать нижний divider.
final
subtitle String?
Второстепенный текст под заголовком.
final
title String?
Заголовок панели.
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited