CarpenterType class

Dynamic typography visual runtime.

Constructors

CarpenterType(Map<String, TextStyle> tokens, {Map<String, TextStyle> secondaryTokens = const {}})
Создает typography registry.
const
CarpenterType.fromConfig({required CarpenterTypeConfig config, required double baseSize})
Создает typography runtime из config.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
hasSecondary bool
Настроен ли отдельный вторичный font family.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secondaryTokens Map<String, TextStyle>
Вторичные текстовые роли. Пусты, если secondary family не настроен.
final
tokens Map<String, TextStyle>
Dynamic registry текстовых ролей.
final

Methods

call(String role) TextStyle
Возвращает TextStyle по роли.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
secondary(String role) TextStyle
Возвращает вторичный TextStyle или основной, если он не настроен.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited
operator [](String role) TextStyle
Возвращает TextStyle по роли.