CarpenterWorkflowController<TState, TContext> class abstract interface

Implemented types
Implementers

Properties

availableTransitions List<CarpenterWorkflowTransition<TState, TContext>>
no setter
completed bool
no setter
context → TContext
no setter
error Object?
no setter
executing bool
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state → TState
no setter

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object notifies its listeners.
inherited
cancel() Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that the object notifies.
inherited
retry() Future<void>
toString() String
A string representation of this object.
inherited
transition(CarpenterWorkflowTransition<TState, TContext> transition) Future<void>

Operators

operator ==(Object other) bool
The equality operator.
inherited