CarpenterWorkflowControllerBase<TState, TContext> class
- Inheritance
-
- Object
- ChangeNotifier
- CarpenterWorkflowControllerBase
- Implemented types
-
- CarpenterWorkflowController<
TState, TContext>
- CarpenterWorkflowController<
Constructors
-
CarpenterWorkflowControllerBase({required TState initialState, required TContext context, required List<
CarpenterWorkflowTransition< transitions(TState state, TContext context), required TState reduce(TState state, CarpenterWorkflowTransitionId transition), Future<TState, TContext> >void> onCancel()?})
Properties
-
availableTransitions
→ List<
CarpenterWorkflowTransition< TState, TContext> > -
no setteroverride
- completed ↔ bool
-
getter/setter pairoverride-getter
- context → TContext
-
final
- error ↔ Object?
-
getter/setter pairoverride-getter
- executing ↔ bool
-
getter/setter pairoverride-getter
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state → TState
-
no setteroverride
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
cancel(
) → Future< void> -
override
-
dispose(
) → void -
Discards any resources used by the object.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
retry(
) → Future< void> -
override
-
toString(
) → String -
A string representation of this object.
inherited
-
transition(
CarpenterWorkflowTransition< TState, TContext> transition) → Future<void> -
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited