CarpenterWorkflowStage<TState, TContext> class
abstract
Constructors
- CarpenterWorkflowStage({required String id, required String title, required bool when(TState state, TContext context), String? description})
-
const
Properties
Methods
-
build(
BuildContext context, TState state, TContext workflowContext) → Widget -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited