CarpenterWorkflowTransition<TState, TContext> class final

Constructors

CarpenterWorkflowTransition({required CarpenterWorkflowTransitionId id, required String title, required bool canExecute(TState state, TContext context), required Future<void> execute(TContext context)})
const

Properties

canExecute bool Function(TState state, TContext context)
final
execute Future<void> Function(TContext context)
final
hashCode int
The hash code for this object.
no setterinherited
id CarpenterWorkflowTransitionId
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited