ActionColorRole enum
Semantic color family for interactive actions.
Values
- neutral → const ActionColorRole
-
Neutral action without product or status emphasis.
- primary → const ActionColorRole
-
Primary product action.
- utility → const ActionColorRole
-
Utility or tooling action that is useful but not the main task.
- danger → const ActionColorRole
-
Destructive or dangerous action.
- warning → const ActionColorRole
-
Cautionary action whose consequences deserve warning emphasis.
- success → const ActionColorRole
-
Action associated with a successful or positive outcome.
- info → const ActionColorRole
-
Informational action without success, warning, or danger semantics.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
ActionColorRole> - A constant List of the values in this enum, in order of their declaration.