CarpenterActionPalette class final
State palette for one semantic action color family.
- Annotations
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- hovered → Color
-
Color used when the action is hovered.
final
- normal → Color
-
Default foreground/state color for the action family.
final
- pressed → Color
-
Color used while the action is pressed.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state → Color
-
Low-intensity semantic state color used for tinted surfaces.
final
- strongState → Color
-
Higher-intensity semantic state color used for emphasized surfaces.
final
Methods
-
copyWith(
{Color? normal, Color? hovered, Color? pressed, Color? state, Color? strongState}) → CarpenterActionPalette -
Resolves the action-family color for
states, preferring pressed, then hovered, then normal. Returns this action-family palette with only the supplied interaction colors replaced. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resolve(
Set< WidgetState> states) → Color -
Resolves this action palette for the supplied interaction
states. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited