CarpenterActionTheme class final
Resolves semantic action color roles, prominence, and interaction state without requiring components to choose raw colors.
- Annotations
Constructors
- CarpenterActionTheme({required CarpenterActionPalette neutral, required CarpenterActionPalette primary, required CarpenterActionPalette utility, required CarpenterActionPalette danger, required CarpenterActionPalette warning, required CarpenterActionPalette success, required CarpenterActionPalette info, required Color transparent, required Color inverse, required Color disabledBackground, required Color disabledForeground})
-
Creates the action theme from semantic palettes and shared disabled/inverse colors.
const
Properties
- danger → CarpenterActionPalette
-
Palette for destructive actions.
final
- disabledBackground → Color
-
Shared disabled action background used by filled/tinted prominence.
final
- disabledForeground → Color
-
Shared disabled foreground used for action text, icons, borders, and loading accents.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- info → CarpenterActionPalette
-
Palette for informational actions.
final
- inverse → Color
-
Inverse foreground used on filled semantic action surfaces.
final
- neutral → CarpenterActionPalette
-
Palette for neutral actions.
final
- primary → CarpenterActionPalette
-
Palette for primary product actions.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- success → CarpenterActionPalette
-
Palette for positive/success actions.
final
- transparent → Color
-
Transparent color used when prominence calls for no filled surface or border.
final
- utility → CarpenterActionPalette
-
Palette for utility/tooling actions.
final
- warning → CarpenterActionPalette
-
Palette for cautionary actions.
final
Methods
-
copyWith(
{CarpenterActionPalette? neutral, CarpenterActionPalette? primary, CarpenterActionPalette? utility, CarpenterActionPalette? danger, CarpenterActionPalette? warning, CarpenterActionPalette? success, CarpenterActionPalette? info, Color? transparent, Color? inverse, Color? disabledBackground, Color? disabledForeground}) → CarpenterActionTheme -
Resolves action colors from semantic
role, visualprominence, and interactionstates, including disabled treatment. Returns an action theme with only the supplied semantic palettes or shared colors replaced. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resolve(
ActionColorRole role, ActionProminence prominence, Set< WidgetState> states) → CarpenterActionStyle - Resolves action colors from semantic role, prominence, and interaction state.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited