CarpenterBreakpointRegionPolicy class final
- Implemented types
- Annotations
Constructors
- CarpenterBreakpointRegionPolicy({required CarpenterRegionPresentation narrow, required CarpenterRegionPresentation medium, required CarpenterRegionPresentation wide})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- medium → CarpenterRegionPresentation
-
final
- narrow → CarpenterRegionPresentation
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- wide → CarpenterRegionPresentation
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resolve(
CarpenterAdaptiveContext context, CarpenterRegionRole role) → CarpenterRegionPresentation -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited