CarpenterContentTheme class final
Semantic foreground palette for non-interactive content.
- Annotations
Constructors
Properties
- disabled → Color
-
Foreground used for unavailable content.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- inverse → Color
-
Foreground intended for inverse or strongly colored surfaces.
final
- muted → Color
-
De-emphasized foreground for tertiary metadata.
final
- primary → Color
-
Primary readable foreground for normal content.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- secondary → Color
-
Secondary foreground for supporting content.
final
Methods
-
copyWith(
{Color? primary, Color? secondary, Color? muted, Color? inverse, Color? disabled}) → CarpenterContentTheme -
Resolves a semantic content color
roleto its raw foreground color. Returns a content palette with only the supplied semantic foregrounds replaced. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resolve(
ContentColorRole role) → Color -
Resolves the semantic foreground color assigned to
role. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited