CarpenterCoreRuntime class final
Core non-visual capability exposed by Carpenter application hosts.
Constructors
- CarpenterCoreRuntime({required TargetPlatform platform, Locale? locale})
-
Creates core runtime capability for the effective platform and optional locale.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- locale → Locale?
-
Optional locale propagated as part of the core Carpenter runtime or application
root.
final
- platform → TargetPlatform
-
Target platform used for platform-sensitive Carpenter behavior.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited