CarpenterDomainWorkflowStage<TState, TContext> class
final
- Inheritance
-
- Object
- CarpenterWorkflowStage<
TState, TContext> - CarpenterDomainWorkflowStage
Constructors
- CarpenterDomainWorkflowStage({required String id, required String title, required bool when(TState state, TContext context), required Widget block(BuildContext context, TState state, TContext workflowContext), String? description})
-
const
Properties
- block → Widget Function(BuildContext context, TState state, TContext workflowContext)
-
final
- description → String?
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title → String
-
finalinherited
- when → bool Function(TState state, TContext context)
-
finalinherited
Methods
-
build(
BuildContext context, TState state, TContext workflowContext) → Widget -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited