fixedHeight property
Whether the control uses the themed fixed field height. When false, the field may grow beyond its themed minimum height for multiline content.
Implementation
final bool fixedHeight;
Whether the control uses the themed fixed field height. When false, the field may grow beyond its themed minimum height for multiline content.
final bool fixedHeight;