CarpenterFieldStyle class final
Resolved field colors after availability, focus, hover, and validation state have been applied.
- Annotations
Constructors
Properties
- background → Color
-
Resolved field background.
final
- border → Color
-
Resolved field border.
final
- error → Color
-
Resolved validation-error foreground.
final
- foreground → Color
-
Resolved editable/readable value foreground.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- icon → Color
-
Resolved field icon foreground.
final
- label → Color
-
Resolved field-label foreground.
final
- placeholder → Color
-
Resolved placeholder foreground.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selection → Color
-
Resolved text-selection/accent color.
final
- supporting → Color
-
Resolved supporting/help text foreground.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited