CarpenterHotkeyPhase enum
Identifies the hardware-key event phase captured in a hotkey snapshot.
Values
- down → const CarpenterHotkeyPhase
-
A physical key transitioned from released to pressed.
- repeat → const CarpenterHotkeyPhase
-
A held key emitted a repeat event.
- up → const CarpenterHotkeyPhase
-
A physical key transitioned from pressed to released.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
CarpenterHotkeyPhase> - A constant List of the values in this enum, in order of their declaration.