CarpenterHotkeySnapshot class final
Immutable snapshot of currently pressed logical and physical keys plus the most recent key event and phase.
- Annotations
Constructors
-
CarpenterHotkeySnapshot({required Set<
LogicalKeyboardKey> logicalKeys, required Set<PhysicalKeyboardKey> physicalKeys, LogicalKeyboardKey? lastLogicalKey, PhysicalKeyboardKey? lastPhysicalKey, CarpenterHotkeyPhase? phase}) -
Creates an immutable logical/physical pressed-key snapshot with optional
most-recent keys and phase.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasPressedKeys → bool
-
Whether at least one logical key is currently pressed.
no setter
- lastLogicalKey → LogicalKeyboardKey?
-
Logical key from the most recently observed hardware-key event, if any.
final
- lastPhysicalKey → PhysicalKeyboardKey?
-
Physical key from the most recently observed hardware-key event, if any.
final
-
logicalKeys
→ Set<
LogicalKeyboardKey> -
Logical keyboard keys currently reported as pressed.
final
- phase → CarpenterHotkeyPhase?
-
Phase of the most recently observed hardware-key event, if any.
final
-
physicalKeys
→ Set<
PhysicalKeyboardKey> -
Physical keyboard keys currently reported as pressed.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- empty → const CarpenterHotkeySnapshot
- Canonical snapshot with no pressed logical or physical keys.