CarpenterKanbanCardState<C> class
final
- Annotations
Constructors
- CarpenterKanbanCardState({required C column, required int index, required bool dragging, required bool hovering, required bool acceptsDrop, CarpenterDropPosition? dropPosition})
-
const
Properties
- acceptsDrop → bool
-
final
- column → C
-
final
- dragging → bool
-
final
- dropPosition → CarpenterDropPosition?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hovering → bool
-
final
- index → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited