CarpenterNotification class final
- Annotations
Constructors
- CarpenterNotification({required Object id, required String title, String? message, FeedbackColorRole tone = FeedbackColorRole.info, DateTime? timestamp, bool unread = false, CarpenterActionDescriptor? action})
-
const
Properties
- action → CarpenterActionDescriptor?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → Object
-
final
- message → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timestamp → DateTime?
-
final
- title → String
-
final
- tone → FeedbackColorRole
-
final
- unread → bool
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited