CarpenterPlanningLane<L, C, T> class
final
- Annotations
Constructors
-
CarpenterPlanningLane({required Object id, required L value, required String title, required List<
CarpenterKanbanColumn< columns, String? semanticLabel})C, T> > -
const
Properties
-
columns
→ List<
CarpenterKanbanColumn< C, T> > -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → Object
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- semanticLabel → String?
-
final
- title → String
-
final
- value → L
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited