CarpenterReorderItemState class final
- Annotations
Constructors
- CarpenterReorderItemState({required int index, required bool dragging, required bool hovering, required bool accepts, CarpenterDropPosition? dropPosition})
-
const
Properties
- accepts → bool
-
final
- dragging → bool
-
final
- dropPosition → CarpenterDropPosition?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hovering → bool
-
final
- index → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited