CarpenterRequestLease<C extends CarpenterCancellationSignal> class
final
One asynchronous request admitted by a CarpenterRequestGate.
A lease remains current until a newer lease starts, the gate is cancelled, or the current lease is finished. Callers should ignore results from leases for which CarpenterRequestGate.isCurrent is false.
- Annotations
Properties
- cancellation → C
-
Gate-owned signal for this request. Observe it, but let the gate manage
its disposal.
final
- generation → int
-
Monotonically increasing admission number within the owning gate.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited