CarpenterResourceController<T> class
Extensible resource lifecycle base for application-specific controllers.
- Inheritance
-
- Object
- ChangeNotifier
- ValueNotifier<
CarpenterPageState> - CarpenterResourceController
- Implemented types
Constructors
-
CarpenterResourceController({required CarpenterResourceLoader<
T> load, String errorMessage(Object error)?})
Properties
- data → T?
-
no setter
- errorMessage → String Function(Object error)?
-
final
- hasData → bool
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- hasRefreshFailure → bool
-
no setter
-
pageCommands
→ List<
CarpenterCommand> -
no setteroverride
-
refreshCommand
↔ CarpenterCommandController<
void> -
latefinal
- refreshFailure → CarpenterResourceFailure?
-
no setter
-
retryCommand
↔ CarpenterCommandController<
void> -
latefinal
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value ↔ CarpenterPageState
-
The current value stored in this notifier.
getter/setter pairinherited
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
didChangeData(
T? previous, T next) → void - Called after resource data changes from load, refresh, replace, or update.
-
dispose(
) → void -
Discards any resources used by the object.
override
-
initialize(
) → Future< void> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
refresh(
) → Future< void> -
override
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
replaceData(
T next) → void - Replaces the currently loaded resource without starting a new request.
-
toString(
) → String -
A string representation of this object.
inherited
-
updateData(
T update(T current)) → void - Replaces the currently loaded resource using its latest value.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited