CarpenterRouteContext class final
Immutable rendering context passed to Carpenter route page, shell, and scope builders.
Constructors
-
CarpenterRouteContext({required CarpenterRuntime runtime, required CarpenterRouteMatch match, required List<
CarpenterRouteMatch> chain}) -
Creates route rendering context for one
matchand its complete activechain.const
Properties
-
arguments
→ Map<
String, String> -
String route arguments carried by the current navigation node.
no setter
-
chain
→ List<
CarpenterRouteMatch> -
Full active matched chain from root declaration through the terminal node.
final
-
extra
→ Map<
String, Object?> -
Typed extra payload carried by the current navigation node.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- match → CarpenterRouteMatch
-
Current declaration/node match being rendered.
final
- node → RouteNode
-
Convenience access to the current yx_navigation node.
no setter
- route → CarpenterRoute
-
Convenience access to the current Carpenter route declaration.
no setter
- runtime → CarpenterRuntime
-
Compiled application runtime available while rendering the route.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited