CarpenterRouteMatch class final
One declaration/node pair in the currently matched active route chain.
Constructors
- CarpenterRouteMatch({required RouteNode node, required CarpenterRoute route, required int depth})
-
Creates a matched route entry at its zero-based depth in the active
declaration chain.
const
Properties
- depth → int
-
Zero-based depth of this match within the active chain.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- node → RouteNode
-
Concrete yx_navigation route-tree node that matched the declaration.
final
- route → CarpenterRoute
-
Carpenter declaration matched to node.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited