CarpenterSelectionController<T> class
final
- Inheritance
-
- Object
- ChangeNotifier
- CarpenterSelectionController
- Implemented types
Constructors
- CarpenterSelectionController({required Object identity(T item), CarpenterSelectionMode mode = CarpenterSelectionMode.multiple})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- hasSelection → bool
-
no setter
- identity → Object Function(T item)
-
final
- length → int
-
no setter
- mode → CarpenterSelectionMode
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
selectedIds
→ Set<
Object> -
no setter
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
clear(
) → void -
deselect(
T item) → void -
dispose(
) → void -
Discards any resources used by the object.
inherited
-
isSelected(
T item) → bool -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
select(
T item) → void -
selectVisible(
Iterable< T> items) → void -
toggle(
T item) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited