CarpenterShellBuildContext class final
Immutable context supplied when an already configured shell wraps hosted content.
Constructors
- CarpenterShellBuildContext({required CarpenterRuntime runtime, required BuildContext buildContext})
-
Creates build context from the final compiled runtime and current Flutter
build context.
const
Properties
- buildContext → BuildContext
-
Flutter build context at the host boundary where shell wrapping occurs.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtime → CarpenterRuntime
-
Final compiled runtime available while the shell wraps content.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited