CarpenterTableFooterCellBuilder<T> typedef
CarpenterTableFooterCellBuilder<T> =
Widget Function(BuildContext context, List<T> items)
Builds one footer cell from all rows currently supplied to the editable table. Calculate totals from items rather than maintaining a second independent list.
Implementation
typedef CarpenterTableFooterCellBuilder<T> =
Widget Function(BuildContext context, List<T> items);