CarpenterToolbarItem class final
- Annotations
Constructors
- CarpenterToolbarItem({required CarpenterActionDescriptor action, CarpenterToolbarGroup group = CarpenterToolbarGroup.secondary, @Deprecated('Use group instead. Priority is retained for compatibility.') CarpenterToolbarPriority? priority, CarpenterToolbarPresentation presentation = CarpenterToolbarPresentation.label, ActionProminence prominence = ActionProminence.ghost, ControlSize size = ControlSize.medium, ActionExecutionPhase executionPhase = ActionExecutionPhase.idle})
-
const
Properties
- action → CarpenterActionDescriptor
-
final
- effectiveGroup → CarpenterToolbarGroup
-
no setter
- executionPhase → ActionExecutionPhase
-
final
- group → CarpenterToolbarGroup
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- presentation → CarpenterToolbarPresentation
-
final
- priority → CarpenterToolbarPriority
-
no setter
- prominence → ActionProminence
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size → ControlSize
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited