CarpenterTypographyTheme class final
Resolves semantic Carpenter typography roles and component text treatments into Flutter TextStyle values using the active unit scale.
- Annotations
Constructors
- CarpenterTypographyTheme()
-
Creates the stateless typography resolver backed by Carpenter tokens.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
action(
BuildContext context, ControlSize size, TypographyEmphasis emphasis) → TextStyle -
Resolves action-label typography for a semantic control
sizeandemphasis. -
dialogTitle(
BuildContext context, TypographyEmphasis emphasis) → TextStyle - Resolves dialog-title typography using overlay dialog tokens.
-
fieldInput(
BuildContext context, FieldSize size, TypographyEmphasis emphasis) → TextStyle -
Resolves editable field-value typography for
sizeandemphasis. -
fieldLabel(
BuildContext context, FieldSize size, TypographyEmphasis emphasis) → TextStyle -
Resolves field-label typography for
sizeandemphasis. -
fieldSupporting(
BuildContext context, FieldSize size, TypographyEmphasis emphasis) → TextStyle -
Resolves field supporting/help typography for
sizeandemphasis. - Resolves menu-item typography using the menu component tokens.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resolve(
BuildContext context, TypographyRole role, TypographyEmphasis emphasis) → TextStyle -
Resolves general semantic typography
roleandemphasisinto a unit-aware text style. -
selectionLabel(
BuildContext context, ControlSize size, TypographyEmphasis emphasis) → TextStyle -
Resolves selection-control primary-label typography for
sizeandemphasis. -
selectionSupporting(
BuildContext context, ControlSize size, TypographyEmphasis emphasis) → TextStyle -
Resolves selection-control supporting-label typography for
sizeandemphasis. -
status(
BuildContext context, TypographyEmphasis emphasis) → TextStyle - Resolves status-indicator typography using the status component tokens.
-
tableCell(
BuildContext context, TypographyEmphasis emphasis) → TextStyle - Resolves table-cell typography using table component tokens.
-
tableHeader(
BuildContext context, TypographyEmphasis emphasis) → TextStyle - Resolves table-header typography using table component tokens.
-
toastMessage(
BuildContext context, TypographyEmphasis emphasis) → TextStyle - Resolves toast-message typography using overlay toast tokens.
-
toastTitle(
BuildContext context, TypographyEmphasis emphasis) → TextStyle - Resolves toast-title typography using overlay toast tokens.
-
tooltip(
BuildContext context, TypographyEmphasis emphasis) → TextStyle - Resolves tooltip typography using overlay tooltip tokens.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited