CollectionOffsetPageRequest class final
Requests a bounded range using a zero-based offset. Use only when the data source supports offset pagination.
- Inheritance
-
- Object
- CollectionPageRequest
- CollectionOffsetPageRequest
Constructors
- CollectionOffsetPageRequest({required int offset, required int limit})
-
Creates an offset request. Asserts that
offsetis nonnegative andlimitis positive.const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- limit → int
-
Maximum requested number of items; must be greater than zero.
final
- offset → int
-
Number of matching items to skip before returning the page.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited