LengthUnitContext class final
Runtime values required to resolve relative length units.
Constructors
- LengthUnitContext({required double rootFontSize, double? currentFontSize})
-
Creates a length-resolution context.
const
Properties
- currentFontSize → double?
-
Current font size in Flutter logical pixels, when available.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- rootFontSize → double
-
Root font size in Flutter logical pixels.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited