Rem class final
A value relative to the root rem configured for the widget subtree.
- Inheritance
-
- Object
- Unit
- LengthUnit
- Rem
Properties
- canonical → String
-
A deterministic authoring representation of this unit.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- symbol → String
-
The canonical suffix for this unit.
no setteroverride
- value → double
-
Numeric magnitude of this unit.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resolve(
LengthUnitContext context) → double -
Resolves this unit to Flutter logical pixels.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited