RouteNodeDiffResult class final
Describes the difference between two RouteNode trees.
The diff contains three buckets keyed by YxRoute:
- Annotations
Constructors
-
RouteNodeDiffResult(Map<
YxRoute, RouteNode> added, Map<YxRoute, RouteNode> removed, Map<YxRoute, Mutation> updates) -
Describes the difference between two RouteNode trees.
const
- RouteNodeDiffResult.difference(RouteNode originalNode, RouteNode targetNode)
-
Computes the diff between
originalNodeandtargetNode.factory
Properties
-
added
→ Map<
YxRoute, RouteNode> -
Nodes introduced by the mutation.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isEmpty → bool
-
Whether the diff contains no additions, removals or updates.
no setter
- isNotEmpty → bool
-
Whether the diff contains any additions, removals or updates.
no setter
-
removed
→ Map<
YxRoute, RouteNode> -
Nodes that disappeared as a result of the mutation.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
updates
→ Map<
YxRoute, Mutation> -
Routes that changed payload between the original and target trees.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited