RouteObserverAdapter class final
- Inheritance
-
- Object
- YxRouteObserver
- RouteObserverAdapter
- Annotations
-
- @experimental
Constructors
- RouteObserverAdapter(YxRoute route, YxRouteObserver? sourceObserver)
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- onPop → PopRouteMutationCallback?
-
Called when the observed route is removed from the tree.
finalinherited
- onPush → PopRouteMutationCallback?
-
Called when the observed route is added to the tree.
finalinherited
- onUpdate → PopRouteMutationCallback?
-
Called when the observed route's data changes.
finalinherited
- route → YxRoute
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sourceObserver → YxRouteObserver?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onRouteDiffMutation(
Mutation mutation, RouteNodeDiffResult diff) → void -
Called with every mutation that touched the observed route.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited