SquidPathBasedSerializer class abstract
Path-based serializer for navigation state.
Serializes RouteNode tree to URL path (without #).
Example: /root/.child1/..child2
This is useful for scenarios where third parties ignore the hash (#) in redirect URLs, such as OAuth callbacks or Telegram login redirects.
See also:
- SquidFragmentBasedSerializer for fragment-based serialization
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited