CarpenterCollectionPage<T, TFilter, TSort> class
Standard page composition for collection scenarios.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- CarpenterCollectionPage
Constructors
-
CarpenterCollectionPage({Key? key, required CarpenterPageDescriptor descriptor, Widget? collection, CarpenterDataCollectionController<
T, TFilter, TSort> ? dataController, Object itemIdentity(T item)?, CarpenterDataCollectionItemBuilder<T> ? itemBuilder, List<CarpenterDataGroup< groupBy(List<T> >T> items)?, List<Widget> itemActionsBuilder(BuildContext context, T item)?, ValueChanged<T> ? onItemActivate, CarpenterEmptyStateDescriptor? empty, CarpenterEmptyStateDescriptor? filteredEmpty, CarpenterPageController? pageController, CarpenterPageState state = const CarpenterPageReady(), Widget? header, Widget? summary, Widget? queryBar, Widget? filterBar, Widget? actionBar, Widget? selectionBar, List<CarpenterPageCapability> capabilities = const [], List<CarpenterCommand> commands = const [], List<CarpenterCommandBinding> commandBindings = const []}) -
const
Properties
- actionBar → Widget?
-
final
-
capabilities
→ List<
CarpenterPageCapability> -
final
- collection → Widget?
-
final
-
commandBindings
→ List<
CarpenterCommandBinding> -
final
-
commands
→ List<
CarpenterCommand> -
final
-
dataController
→ CarpenterDataCollectionController<
T, TFilter, TSort> ? -
final
- descriptor → CarpenterPageDescriptor
-
final
- empty → CarpenterEmptyStateDescriptor?
-
final
- filterBar → Widget?
-
final
- filteredEmpty → CarpenterEmptyStateDescriptor?
-
final
-
groupBy
→ List<
CarpenterDataGroup< Function(List<T> >T> items)? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- header → Widget?
-
final
-
itemActionsBuilder
→ List<
Widget> Function(BuildContext context, T item)? -
final
-
itemBuilder
→ CarpenterDataCollectionItemBuilder<
T> ? -
final
- itemIdentity → Object Function(T item)?
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
-
onItemActivate
→ ValueChanged<
T> ? -
final
- pageController → CarpenterPageController?
-
final
- queryBar → Widget?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selectionBar → Widget?
-
final
- state → CarpenterPageState
-
final
- summary → Widget?
-
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited