CarpenterColorScaleConfig class
Настройка одной цветовой шкалы.
Constructors
-
CarpenterColorScaleConfig({Color? seed, Iterable<
String> steps = carpenterDefaultColorSteps, Map<String, Color> colors = const {}, bool neutral = false, double? chroma}) -
Создает настройку шкалы.
const
-
CarpenterColorScaleConfig.explicit(Map<
String, Color> colors) -
Полностью явная шкала.
const
-
CarpenterColorScaleConfig.seed(Color seed, {Iterable<
String> steps = carpenterDefaultColorSteps, Map<String, Color> overrides = const {}, bool neutral = false, double? chroma}) -
Шкала, сгенерированная из seed через OKLCH.
const
Properties
- chroma → double?
-
Chroma override для generated шкалы.
final
-
colors
→ Map<
String, Color> -
Явные значения или partial overrides.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- neutral → bool
-
Делает шкалу почти нейтральной, сохраняя легкую привязку к hue seed.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- seed → Color?
-
Seed-цвет для генерации.
final
-
steps
→ Iterable<
String> -
Любые шаги шкалы в нужном порядке.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited