CarpenterControlState class
Состояние интерактивного primitive CarpenterControl.
Компоненты используют это состояние в builder, чтобы визуально реагировать на доступность, hover, focus и pressed без дублирования pointer/keyboard логики.
Constructors
- CarpenterControlState({required bool enabled, required bool hovered, required bool focused, required bool pressed})
-
Создает снимок интерактивного состояния.
const
Properties
- enabled → bool
-
Элемент доступен пользователю и может быть активирован.
final
- focused → bool
-
Элемент находится в focus-highlight состоянии.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hovered → bool
-
Указатель находится над элементом.
final
- pressed → bool
-
Элемент сейчас нажат.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited