CarpenterDataCollection<T, TFilter, TSort> class
Functional collection block with state, selection and pagination behavior.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- CarpenterDataCollection
Constructors
-
CarpenterDataCollection({Key? key, required CarpenterDataCollectionController<
T, TFilter, TSort> controller, required Object itemIdentity(T item), required CarpenterDataCollectionItemBuilder<T> itemBuilder, List<CarpenterDataGroup< groupBy(List<T> >T> items)?, List<Widget> itemActionsBuilder(BuildContext context, T item)?, ValueChanged<T> ? onItemActivate, CarpenterEmptyStateDescriptor? empty, CarpenterEmptyStateDescriptor? filteredEmpty, Widget? separator, EdgeInsetsGeometry? padding}) -
const
Properties
-
controller
→ CarpenterDataCollectionController<
T, TFilter, TSort> -
final
- empty → CarpenterEmptyStateDescriptor?
-
final
- filteredEmpty → CarpenterEmptyStateDescriptor?
-
final
-
groupBy
→ List<
CarpenterDataGroup< Function(List<T> >T> items)? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
itemActionsBuilder
→ List<
Widget> Function(BuildContext context, T item)? -
final
-
itemBuilder
→ CarpenterDataCollectionItemBuilder<
T> -
final
- itemIdentity → Object Function(T item)
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
-
onItemActivate
→ ValueChanged<
T> ? -
final
- padding → EdgeInsetsGeometry?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- separator → Widget?
-
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< CarpenterDataCollection< T, TFilter, TSort> > -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited