CarpenterDataGroup<T> class
final
Constructors
-
CarpenterDataGroup({required Object id, required Widget header, required List<
T> items, bool collapsible = true, bool initiallyExpanded = true, ValueChanged<bool> ? onExpandedChanged}) -
const
Properties
- collapsible → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- header → Widget
-
final
- id → Object
-
final
- initiallyExpanded → bool
-
final
-
items
→ List<
T> -
final
-
onExpandedChanged
→ ValueChanged<
bool> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited