CarpenterDimensionConfig class
Настройка размерного runtime.
Размерности Carpenter являются dynamic registry. Можно задавать любые роли
для space, radius, size и произвольных tokens.
Constructors
Properties
- density → double
-
Плотность интерфейса.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
radius
→ Map<
String, double> -
Радиусы.
final
- rem → double
-
Базовая единица размера.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
size
→ Map<
String, double> -
Размеры controls, icons, avatars и других элементов.
final
-
space
→ Map<
String, double> -
Отступы и интервалы.
final
-
tokens
→ Map<
String, double> -
Произвольные размерные токены.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited