- Implemented types
- Implementers
Properties
-
fields
→ List<
CarpenterFieldBinding> -
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- mode → CarpenterEditorMode
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → CarpenterEditorState
-
The current value of the object.
no setterinherited
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object notifies its listeners.
inherited
-
cancel(
) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that the
object notifies.
inherited
-
save(
) → Future< TRecord?> -
toString(
) → String -
A string representation of this object.
inherited
-
validate(
) → Future< bool>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited