CarpenterFormWorkflowStage<TState, TContext> class
A workflow stage composed from fields. Carpenter owns the card, labels, vertical rhythm, scrolling and keyboard submission.
- Inheritance
-
- Object
- CarpenterWorkflowStage<
TState, TContext> - CarpenterFormWorkflowStage
Constructors
Properties
- description → String?
-
finalinherited
-
fields
→ List<
Widget> Function(TState state, TContext context) -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title → String
-
finalinherited
- when → bool Function(TState state, TContext context)
-
finalinherited
Methods
-
build(
BuildContext context, TState state, TContext workflowContext) → Widget -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited