CarpenterHotkeyFormatter class
Форматтер hotkey-комбинаций под платформу.
macOS получает символы ⌘, ⌥, ⌃, ⇧, а Windows/Linux - привычные
текстовые модификаторы. Сам форматтер не зависит от BuildContext, поэтому
его удобно тестировать и переиспользовать в документации.
Constructors
- CarpenterHotkeyFormatter({required TargetPlatform platform})
-
Создает форматтер для платформы.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- platform → TargetPlatform
-
Платформа, под которую форматируются подписи.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
formatActivator(
ShortcutActivator activator) → String -
Форматирует
ShortcutActivatorиз Flutter Shortcuts. -
formatPressedKeys(
Iterable< LogicalKeyboardKey> keys) → String - Форматирует набор сейчас зажатых logical keys.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited