Минимальный нейтральный набор glyph ids. Приложение может заменить его собственным icon font через отдельный компонентный adapter.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- accept → const IconData
- account → const IconData
- add → const IconData
- archive → const IconData
- arrowDownFilled → const IconData
- arrowUpRight → const IconData
- back → const IconData
- bank → const IconData
- bankSolid → const IconData
- branchFork → const IconData
- calendar → const IconData
- chevronLeft → const IconData
- chevronRight → const IconData
- clear → const IconData
- code → const IconData
- completedSolid → const IconData
- copy → const IconData
- download → const IconData
- edit → const IconData
- errorBadge → const IconData
- file → const IconData
- info → const IconData
- list → const IconData
- lock → const IconData
- more → const IconData
- next → const IconData
- openFile → const IconData
- paymentCard → const IconData
- refresh → const IconData
- removeLink → const IconData
- restore → const IconData
- save → const IconData
- search → const IconData
- sortDown → const IconData
- sortUp → const IconData
- tree → const IconData
- upload → const IconData
- warning → const IconData