Независимый feature module Carpenter.
Модуль приносит собственные routes и, если нужно, shell-и/capabilities. Ядро приложения только подключает модули и не знает их внутренние pages.
- Implementers
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
Стабильный id модуля.
no setter
-
provides
→ Set<
Type> -
Capabilities, которые модуль обещает предоставить своими shell-ами.
no setter
-
requires
→ Set<
Type> -
Capabilities, которые нужны модулю на app-level.
no setter
-
routes
→ List<
CarpenterRoute> -
Root routes модуля.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
shells
→ List<
CarpenterShell> -
Shell-и модуля.
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited