CarpenterMotion class
Motion-токены visual runtime.
Компоненты используют эти значения для единообразных transition и feedback
состояний. Конкретная анимация остается внутри компонента, но ее темп и
кривая приходят из Face.
Constructors
- CarpenterMotion({required Duration fast, required Duration normal, required Duration slow, required Curve curve})
-
Создает набор motion-токенов.
const
- CarpenterMotion.fromConfig(CarpenterConfig config)
-
Создает motion-токены из конфига runtime.
factory
Properties
- curve → Curve
-
Базовая кривая Carpenter.
final
- fast → Duration
-
Быстрое движение для hover, press и небольших feedback-состояний.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- normal → Duration
-
Базовое движение для обычных transitions.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- slow → Duration
-
Медленное движение для крупных раскрытий и смены поверхностей.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited