CarpenterPage class
Infrastructure host shared by every Carpenter page pattern.
New pages should provide descriptor, state or controller, and body. The legacy content/loading API remains available during migration.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- CarpenterPage
Constructors
-
CarpenterPage({Key? key, CarpenterPageDescriptor? descriptor, CarpenterPageController? controller, CarpenterPageState? state, List<
CarpenterCommand> commands = const [], List<CarpenterCommandBinding> commandBindings = const [], List<CarpenterPageCapability> capabilities = const [], Widget? header, Widget? body, Widget? content, Widget? aside, Widget? overlay, bool loading = false, CarpenterPageLoadingPresentation loadingPresentation = CarpenterPageLoadingPresentation.topBar}) -
const
Properties
- aside → Widget?
-
final
- body → Widget?
-
final
-
capabilities
→ List<
CarpenterPageCapability> -
final
-
commandBindings
→ List<
CarpenterCommandBinding> -
final
-
commands
→ List<
CarpenterCommand> -
final
- content → Widget?
-
Compatibility alias for body.
final
- controller → CarpenterPageController?
-
final
- descriptor → CarpenterPageDescriptor?
-
final
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- header → Widget?
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- loading → bool
-
Compatibility input mapped to a typed page state.
final
- loadingPresentation → CarpenterPageLoadingPresentation
-
Compatibility presentation for loading.
final
- overlay → Widget?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state → CarpenterPageState?
-
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited