CarpenterPageRestorationController class final
Namespaced access to a replaceable restoration store.
Constructors
- CarpenterPageRestorationController({required CarpenterPageId pageId, required CarpenterRestorationStore store})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- pageId → CarpenterPageId
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- store → CarpenterRestorationStore
-
final
Methods
-
key<
T> (String name) → CarpenterRestorationKey< T> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
read<
T> (String name) → Future< T?> -
remove(
String name) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
-
write<
T> (String name, T value) → Future< void>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited