CarpenterPaletteConfig class
Настройка primitive palette.
Палитра Carpenter является dynamic registry: названия шкал и шагов ничем не ограничены. Шкалу можно передать целиком, частично переопределить или сгенерировать из seed через OKLCH.
Constructors
-
CarpenterPaletteConfig({Map<
String, CarpenterColorScaleConfig> scales = const {}}) -
Создает настройку primitive palette.
const
- CarpenterPaletteConfig.defaults({required Color primary, required Color accent})
-
Дефолтная palette config из legacy primary/accent.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
scales
→ Map<
String, CarpenterColorScaleConfig> -
Dynamic registry шкал.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited