CarpenterRouteMatch class
Match одного yx node с Carpenter route declaration.
Constructors
- CarpenterRouteMatch({required RouteNode node, required CarpenterRoute route, required int depth})
-
Создает route match.
const
Properties
- depth → int
-
Глубина в active chain.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- node → RouteNode
-
Текущий node из yx_navigation.
final
- route → CarpenterRoute
-
Declaration Carpenter для node.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited