CarpenterRouterRuntime class
Runtime capability router-а Carpenter.
Constructors
- CarpenterRouterRuntime({required RouteNode? root})
-
Создает router runtime.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
Navigation controller из yx_navigation. Его можно использовать без
BuildContextиз commands/interactors/services.final - root → RouteNode?
-
Текущий root route node.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
maybePop(
) → void - Возврат назад, если возможно.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
push(
YxRoute route, {Map< String, String> ? arguments, Map<String, Object?> ? extra}) → void - Пушит route через yx_navigation.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited