CarpenterShellBuildContext class
Контекст shell на этапе widget wrapping.
Constructors
- CarpenterShellBuildContext({required CarpenterRuntime runtime, required BuildContext buildContext})
-
Создает build context shell-а.
const
Properties
- buildContext → BuildContext
-
Flutter context текущей сборки.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtime → CarpenterRuntime
-
Runtime после compile phase.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited