CarpenterTextTone enum
Семантический цвет текста Carpenter.
Values
- primary → const CarpenterTextTone
-
Основной текст.
- secondary → const CarpenterTextTone
-
Второстепенный текст.
- muted → const CarpenterTextTone
-
Приглушенный текст.
- inverse → const CarpenterTextTone
-
Текст на темной или насыщенной поверхности.
- disabled → const CarpenterTextTone
-
Текст недоступного состояния.
- success → const CarpenterTextTone
-
Текст успешного состояния.
- warning → const CarpenterTextTone
-
Текст предупреждения.
- danger → const CarpenterTextTone
-
Текст ошибки или опасного состояния.
- info → const CarpenterTextTone
-
Информационный текст.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
CarpenterTextTone> - A constant List of the values in this enum, in order of their declaration.