CarpenterTopPanelContext class
Контекст сборки верхней панели app-frame.
Constructors
- CarpenterTopPanelContext({required TargetPlatform targetPlatform, required CarpenterFramePlatform framePlatform})
-
Создает контекст верхней панели.
const
Properties
- framePlatform → CarpenterFramePlatform
-
Укрупненный класс платформы для выбора панели.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isDesktop → bool
-
true, если приложение запущено в desktop-окружении.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- targetPlatform → TargetPlatform
-
Реальная Flutter-платформа.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited